<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class webvite_accordion extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve accordion widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'webvite_accordion', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve accordion widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Accordion', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the accordion widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve accordion widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register accordion widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'section',
			[
				'label' => __( 'General Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'accordion-style',
			[
				'label'      => __( 'Select Style', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'accordion-1',
				'options'    => [
					'accordion-1'          => __( 'Style 1', 'webvite' ),
					'accordion-2'          => __( 'Style 2', 'webvite' ),	
					'accordion-3'          => __( 'Style 3', 'webvite' ),
					'accordion-4'          => __( 'Style 4', 'webvite' ),	
				],
			]
		);

		$this->add_control(
			'title_html_tag',
			[
				'label' => __( 'Title HTML Tag', 'webvite' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h6',
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'items_section',
			[
				'label' => __( 'Accordion Items', 'webvite' ),
			]
		);

		$repeater = new Repeater();

        $repeater->add_control(
			'tab_title',
			[
				'label' => __( 'Title & Description', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Accordion Title', 'webvite' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'tab_content',
			[
				'label' => __( 'Content', 'webvite' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'Accordion Content', 'webvite' ),
				'show_label' => false,
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => __( 'Accordion Items', 'webvite' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab_title' => __( ' These cases are perfectly simple.', 'webvite' ),
						'tab_content' => __( 'We make websites are the number one ranked design, build and marketing team. Creative and beautiful websites that will make you more successful. sunt in culpa qui officia deserunt mollit anim id est laborum.', 'webvite' ),
					],
					[
						'tab_title' => __( 'Etiam mollis libero vitae pulvinar bibendum.', 'webvite' ),
						'tab_content' => __( 'We make websites are the number one ranked design, build and marketing team. Creative and beautiful websites that will make you more successful. sunt in culpa qui officia deserunt mollit anim id est laborum.', 'webvite' ),
					],
					[
						'tab_title' => __( 'Sed do eiusmod tempor incididunt ut labore.', 'webvite' ),
						'tab_content' => __( 'We make websites are the number one ranked design, build and marketing team. Creative and beautiful websites that will make you more successful. sunt in culpa qui officia deserunt mollit anim id est laborum.', 'webvite' ),
					],
				],
				'title_field' => '{{{ tab_title }}}',
			]
		);


		$this->add_responsive_control(
			'accordion_space',
			[
				'label' => __( 'Accordion Spacing', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 10,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-item' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'accordion_radius',
			[
				'label' => __( 'Accordion Radius', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'accordion-style'=>['accordion-1','accordion-2','accordion-4']
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .accordion.accordion-1 .accordion-header button' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion.accordion-2 .accordion-header button' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion.accordion-4 .accordion-item' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion.accordion-4 .accordion-item-inner' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->end_controls_section(); 

		$this->start_controls_section(
			'style_icon',
			[
				'label' => __( 'Icon Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'webvite-icon[value]!' => '',
				],
			]
		);

		$this->add_control(
			'webvite-icon',
			[
				'label' => __( 'Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-plus',
					'library' => 'fa-solid',
				],
				'recommended' => [
					'fa-solid' => [
						'chevron-down',
						'angle-down',
						'angle-double-down',
						'caret-down',
						'caret-square-down',
					],
					'fa-regular' => [
						'caret-square-down',
					],
				],
				'skin' => 'inline',
				'label_block' => false,
			]
		);

		$this->add_control(
			'active-icon',
			[
				'label' => __( 'Active Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon_active',
				'default' => [
					'value' => 'fas fa-minus',
					'library' => 'fa-solid',
				],
				'recommended' => [
					'fa-solid' => [
						'chevron-up',
						'angle-up',
						'angle-double-up',
						'caret-up',
						'caret-square-up',
					],
					'fa-regular' => [
						'caret-square-up',
					],
				],
				'skin' => 'inline',
				'label_block' => false,
				'condition' => [
					'webvite-icon[value]!' => '',
				],
			]
		);


		$this->add_control(
			'icon_position',
			[
				'label' => __( 'Alignment', 'webvite' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'accordion-icon-left' => [
						'title' => __( 'Start', 'webvite' ),
						'icon' => 'eicon-h-align-left',
					],
					'accordion-icon-right' => [
						'title' => __( 'End', 'webvite' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => is_rtl() ? 'accordion-icon-right' : 'accordion-icon-left',
				'toggle' => false,
			]
		);

		$this->add_control(
			'icon-style',
			[
				'label'      => __( 'Icon Type', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon-default',
				'options'    => [
					'icon-default'          => __( 'Default', 'webvite' ),
					'icon-flat'          => __( 'Flat', 'webvite' ),			
				]
			]
		);

		$this->start_controls_tabs( 'accordion_icon_style' );

			$this->start_controls_tab(
				'accordion_icon_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'normal_icon_color',
				[
					'label' => __( 'Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .accordion .accordion-header .elementor-accordion-icon-closed i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'normal_icon_bg_color',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => [
						'icon-style'=>['icon-flat']
					],
					'selectors' => [
						'{{WRAPPER}} .accordion.icon-flat .accordion-header .elementor-accordion-icon-closed i' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'accordion_icon_active',
				array(
					'label' => __( 'Active', 'webvite' ),
				)
			);

			$this->add_control(
				'active_icon_color',
				[
					'label' => __( 'Active Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .accordion .accordion-header .elementor-accordion-icon-opened i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'active_icon_bg_color',
				[
					'label' => __( 'Active Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => [
						'icon-style'=>['icon-flat']
					],
					'selectors' => [
						'{{WRAPPER}} .accordion.icon-flat .accordion-header .elementor-accordion-icon-opened i' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 13,   
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-header .accordion-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_radius',
			[
				'label' => __( 'Icon Radius', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'icon-style'=>['icon-flat']
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .accordion.icon-flat .accordion-header .elementor-accordion-icon-closed i' => 'border-radius: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion.icon-flat .accordion-header .elementor-accordion-icon-opened i' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_space',
			[
				'label' => __( 'Spacing', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-icon-left .elementor-accordion-icon-opened' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion .accordion-icon-left .elementor-accordion-icon-closed' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion .accordion-icon-right .elementor-accordion-icon-opened' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .accordion .accordion-icon-right .elementor-accordion-icon-closed' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_toggle_style_title',
			[
				'label' => __( 'Title', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				array(
					'name'     => 'typography',
					'label'    => __( 'Title Typography', 'webvite' ),
					'selector' => '{{WRAPPER}} .accordion .accordion-header .accordion-title button',
				)
			);

			$this->add_responsive_control(
				'accordion_border_width',
				[
					'label' => __( 'Border Width', 'webvite' ),
					'type' => Controls_Manager::SLIDER,
					'condition' => ['accordion-style'=>['accordion-2','accordion-3']],
					'default' => [
						'size' => 1,
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 10,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .accordion.accordion-2 .accordion-header .accordion-title button' => 'border-width: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .accordion.accordion-3 .accordion-item' => 'border-bottom-width: {{SIZE}}{{UNIT}} !important;',
					],
				]
			);

			$this->add_control(
				'accordion_3-4_border_color',
				array(
					'label'     => __( 'Border Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'condition' => ['accordion-style'=>['accordion-3','accordion-4']],
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion.accordion-3 .accordion-item' => 'border-bottom-color: {{VALUE}} !important;',
						'{{WRAPPER}} .accordion.accordion-4 .accordion-item .accordion-item-inner' => 'border-color: {{VALUE}};',
					),
				)
			);

		$this->start_controls_tabs( 'accordion_color_style' );

			$this->start_controls_tab(
				'accordion_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'accordion_normal_title_color',
				array(
					'label'     => __( 'Title Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button.collapsed' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'accordion_normal_border_color',
				array(
					'label'     => __( 'Border Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'condition' => ['accordion-style'=>['accordion-2']],
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button.collapsed' => 'border-color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'accordion_normal_bg_color',
				array(
					'label'     => __( 'Background Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'condition' => ['accordion-style'=>['accordion-1','accordion-4']],
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button.collapsed' => 'background: {{VALUE}};',
						'{{WRAPPER}} .accordion-4 .accordion-item .accordion-button.collapsed' => 'background: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'accordion_active',
				array(
					'label' => __( 'Active', 'webvite' ),
				)
			);

			$this->add_control(
				'accordion_active_title_color',
				array(
					'label'     => __( 'Title Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'accordion_active_border_color',
				array(
					'label'     => __( 'Border Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'condition' => ['accordion-style'=>['accordion-2','accordion-4']],
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button' => 'border-color: {{VALUE}};',
						'{{WRAPPER}} .accordion.accordion-4 .accordion-item .accordion-button:before' => 'background: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'accordion_active_bg_color',
				array(
					'label'     => __( 'Background Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'condition' => ['accordion-style'=>['accordion-1','accordion-2']],
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .accordion .accordion-header .accordion-title button' => 'background: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'accordion_shadow',
				'exclude' => [
					'box_shadow_position',
				],
				'condition' => [
					'accordion-style'	=>['accordion-1','accordion-2']
				],
				'selector' => '	{{WRAPPER}} .accordion.accordion-1 .accordion-header .accordion-title button,
								{{WRAPPER}} .accordion.accordion-2 .accordion-header .accordion-title button'
				,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-header .accordion-title button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'section_toggle_style_content',
			[
				'label' => __( 'Content', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'contact_typography',
				'label'    => __( 'Contact Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .accordion .accordion-body',
			)
		);

		$this->add_control(
			'content_background_color',
			[
				'label' => __( 'Background', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'condition' => ['accordion-style'=>['accordion-11']],
				'selectors' => [
					'{{WRAPPER}} .accordion.accordion-1 .accordion-item .accordion-body' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' => __( 'Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-body' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => __( 'Padding', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .accordion .accordion-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		$settings = $this->get_settings_for_display();
		$migrated = isset( $settings['__fa4_migrated']['webvite-icon'] );

		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
			// @todo: remove when deprecated
			// added as bc in 2.6
			// add old default
			$settings['icon'] = 'fa fa-plus';
			$settings['icon_active'] = 'fa fa-minus';
			$settings['icon_position'] = $this->get_settings( 'icon_position' );
		}

		$is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
		$has_icon = ( ! $is_new || ! empty( $settings['webvite-icon']['value'] ) );
		$id_int = substr( $this->get_id_int(), 0, 3 );

		$icon_style = sprintf('%1$s',esc_html($settings['icon-style'],'webvite'));

		$accordion_style = sprintf('%1$s',esc_html($settings['accordion-style'],'webvite'));

		$i=1;

		?>
		<div class="accordion <?php echo $accordion_style; ?> <?php echo $icon_style; ?>" id="accordion<?php echo esc_attr( $id_int); ?>">
			<?php 
			foreach ( $settings['tabs'] as $index => $item ) : 
			$tab_count = $index + 1;
	
			?>
			<div class="accordion-item">
				<div class="accordion-item-inner">
					<div class="accordion-header" id="heading-<?php echo esc_attr( $id_int . $tab_count ); ?>">
					<<?php echo $settings['title_html_tag']; ?> class="accordion-title">
						<button type="button" data-bs-toggle="collapse" data-bs-target="#accordion-<?php echo esc_attr( $id_int . $tab_count ); ?>" aria-expanded="true" class="accordion-button <?php  if($i != 1){ $coll = "collapsed"; echo esc_attr( $coll ); $i++; } ?>" aria-controls="accordion-<?php echo esc_attr( $id_int . $tab_count ); ?>">
						<span class="accordion-icon <?php echo esc_attr( $settings['icon_position'] ); ?>">
							<?php
							if ( $is_new || $migrated ) { ?>
								<span class="elementor-accordion-icon-closed"><?php Icons_Manager::render_icon( $settings['webvite-icon'] ); ?></span>
								<span class="elementor-accordion-icon-opened"><?php Icons_Manager::render_icon( $settings['active-icon'] ); ?></span>
							<?php } else { ?>
								<i class="elementor-accordion-icon-closed <?php echo esc_attr( $settings['icon'] ); ?>"></i>
								<i class="elementor-accordion-icon-opened <?php echo esc_attr( $settings['icon_active'] ); ?>"></i>
							<?php } ?>
						</span>
						<span class="webvite-accordion-title"><?php echo $item['tab_title']; ?></span>
						</button>
					</<?php echo $settings['title_html_tag']; ?>>
					</div>
					
					<?php  ?>
					<div id="accordion-<?php echo esc_attr( $id_int . $tab_count ); ?>"  class="accordion-collapse collapse <?php  if($i == 1){ $show = "show"; echo esc_attr( $show ); $i++; } ?>" aria-labelledby="heading-<?php echo esc_attr( $id_int . $tab_count ); ?>" data-bs-parent="#accordion<?php echo esc_attr( $id_int); ?>">
					<div class="accordion-body">
						<?php echo $this->parse_text_editor( $item['tab_content'] ); ?>
					</div>
					</div>
					<?php ?>
				</div>
			</div>
			<?php 
			endforeach; ?>
		</div>
		<?php
	}   
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\webvite_accordion() );
?>