<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class Webvite_banner_services extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve list widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'Banner Services', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve list widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Banner Services', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the list widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve list widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register list widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'genral-setting',
			[
				'label' => __( 'Genral Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'banner-services-style',
			[
				'label'      => __( 'Select Style', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'style-1',
				'options'    => [
					'style-1'          => __( 'Style 1', 'webvite' ),
					'style-2'          => __( 'Style 2', 'webvite' ),			
				],
			]
		);

		$this->add_responsive_control(
			'banner-services-height',
			[
				'label' => __( 'Banner Services Height', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 100,
				],
				'size_units' => [ 'px', 'em', '%', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery' => 'height: {{SIZE}}{{UNIT}};',
					'.admin-bar {{WRAPPER}} .slideshow-gallery' => 'height: calc({{SIZE}}{{UNIT}} - 32px);',
				],
			]
		);

		$this->end_controls_section();
			
		$this->start_controls_section(
			'banner-services-setting',
			[
				'label' => __( 'Services Items', 'webvite' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'webvite' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$repeater->add_control(
			'enable-step',
			[
				'label' => __( 'Step', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_control(
			'step-number',
			array(
				'label'       => __( 'Step Number', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => __( '01', 'webvite' ),
				'condition' => ['enable-step' => 'yes'],
			)
		);











		$repeater->add_control(
			'enable-label',
			[
				'label' => __( 'Label', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_control(
			'tab-label',
			array(
				'label'       => __( 'Service Label', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => __( 'Section Label', 'webvite' ),
				'condition' => ['enable-label' => 'yes'],
			)
		);

		$repeater->add_control(
			'enable-title',
			[
				'label' => __( 'Title', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_control(
			'tab-title',
			array(
				'label'       => __( 'Section Title', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => __( 'Section Title', 'webvite' ),
				'condition' => ['enable-title' => 'yes'],
			)
		);









		$repeater->add_control(
			'enable-description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_control(
			'description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'webvite' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'webvite' ),
				'condition' => ['enable-description' => 'yes'],
			]
		);

		$repeater->add_control(
			'enable-link',
			[
				'label' => __( 'Link Enable', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_control(
			'button-text',
			[
				'label' => __( 'Button Text', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
				'default' => __( 'Read More', 'webvite' ),
				'condition' => ['enable-link' => 'yes'],
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'webvite' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'webvite' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['enable-link' => 'yes'],
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => __( 'Banner Services Items', 'webvite' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab-title' => __( 'Banner Services Items', 'webvite' ),  
					]
				],
				'max_items' => 5,
			]
		);		
        

		$this->end_controls_section();

		$this->start_controls_section(
			'content_setting',
			[
				'label' => __( 'Content Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number-typography',
				'selector' => '{{WRAPPER}} .slideshow-gallery .slideshow-number',
			]
		);

		$this->add_control(
			'number_color',
			[
				'label' => __( 'Number Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-number' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'label-typography',
				'selector' => '{{WRAPPER}} .slideshow-gallery .slideshow-label',
			]
		);

		$this->add_control(
			'lable_color',
			[
				'label' => __( 'Lable Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-label' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'selector' => '{{WRAPPER}} .slideshow-gallery .slideshow-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-title' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description-typography',
				'selector' => '{{WRAPPER}} .slideshow-gallery .slideshow-description',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Description Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-description' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_setting',
			[
				'label' => __( 'Button Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'selector' => '{{WRAPPER}} .slideshow-gallery .slideshow-link a',
			]
		);

		$this->add_control(
			'button_radius',
			[
				'label' => __( 'Border Radius', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-link a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'webvite' ),
			]
		);

		$this->add_control(
			'button_normal_color',
			[
				'label' => __( 'Text Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-link a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_background',
			[
				'label' => __( 'Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-link a' => 'background: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'webvite' ),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Text Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-link a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_background',
			[
				'label' => __( 'Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slideshow-gallery .slideshow-link a:hover' => 'background: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
		$tabs = $this->get_settings_for_display( 'tabs' );

		
		?>
		<div class="slideshow-gallery">
			<?php
			if ( $settings['banner-services-style'] === 'style-1' ) {
			?>
				<div class="slideshow-img-item">
					<?php 
					$i=1;
					foreach ( $tabs as $index => $item ){ 
						$url = $item['link']['url'];
						$this->add_render_attribute( 'link-class', 'href', esc_url($url) );
						?>
						<div data-tab="slideshow-image-<?php echo esc_attr($i); ?>" class="image-item <?php if ( $i == 1 ) {
							$show = 'item-active';
							echo esc_attr( $show );
							$i++; } ?>">
							<div class="slideshow-content">
								<div class="content-overlay-image" style="background-image: url(<?php echo esc_url( $item['image']['url'] ); ?>)"></div>
								<div class="content-inner">
									<?php if($item['enable-step'] == 'yes') { ?>
									<h2 class="slideshow-number"><?php echo esc_html($item['step-number'],'webvite'); ?></h2>
									<?php } ?>
									<?php if($item['enable-label'] == 'yes') { ?>
									<div class="slideshow-label"><?php echo esc_html($item['tab-label'],'webvite'); ?></div>
									<?php } ?>
									<?php if($item['enable-title'] == 'yes') { ?>
									<h3 class="slideshow-title"><?php echo esc_html($item['tab-title'],'webvite'); ?></h3>
									<?php } ?>
									<?php if($item['enable-description'] == 'yes') { ?>
									<div class="slideshow-description"><?php echo esc_html($item['description'],'webvite'); ?></div>
									<?php } ?>
									<?php if($item['enable-link'] == 'yes') { ?>
										<div class="slideshow-link"><a <?php echo $this->get_render_attribute_string( 'link-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($item['button-text'],'webvite'));?></span><i class="ti-arrow-right"></i></a></div>
									<?php } ?>
								</div>
							</div>
						</div>
					<?php $i++; }  ?>
				</div>

				<div class="slideshow-img-overlay">
					<?php 
					$i=1;
					foreach ( $tabs as $index => $item ){ ?>
						<div id="slideshow-image-<?php echo esc_attr($i); ?>" class="overlay-item overlay-img-<?php echo $i; ?> <?php if ( $i == 1 ) {
							$show = 'overlay-active';
							echo esc_attr( $show );
							$i++; } ?>">
							<?php if ( ! empty( $item['image']['url'] ) ) { ?>
							<img class="overlay-image image-cover" src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="img1" />
							<?php } ?>
						</div>
					<?php $i++; } ?>
				</div>
			<?php }
			if ( $settings['banner-services-style'] === 'style-2' ) {
			?>
				<div class="slideshow-img-item">
					<div class="slideshow-img-inner">
					<?php 
					$i=1;
					foreach ( $tabs as $index => $item ){ 
						$url = $item['link']['url'];
						$this->add_render_attribute( 'link-class', 'href', esc_url($url) );
						?>
						<div data-tab="slideshow-image-<?php echo esc_attr($i); ?>" class="image-item <?php if ( $i == 1 ) {
							$show = 'item-active';
							echo esc_attr( $show );
							$i++; } ?>">
							<div class="content-inner">
								<?php if($item['enable-label'] == 'yes') { ?>
									<h3 class="slideshow-title"><?php echo esc_html($item['tab-label'],'webvite'); ?></h3>
								<?php } ?>
							</div>
						</div>
					<?php $i++; }  ?>
					</div>
				</div>

				<div class="slideshow-img-overlay">
					<?php 
					$i=1;
					foreach ( $tabs as $index => $item ){ ?>
						<div id="slideshow-image-<?php echo esc_attr($i); ?>" class="overlay-item overlay-img-<?php echo $i; ?> <?php if ( $i == 1 ) {
							$show = 'overlay-active';
							echo esc_attr( $show );
							$i++; } ?>">
							<?php if ( ! empty( $item['image']['url'] ) ) { ?>
							<img class="overlay-image image-cover" src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="img1" />
							<?php } ?>
						</div>
					<?php $i++; } ?>
				</div>
			<?php
			}
			?>
		</div>
	<?php
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\Webvite_banner_services() );
?>