<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class info_box extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve info_box widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'info_box', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve info_box widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Infobox', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the info_box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve info_box widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register info_box widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'genral-setting',
			[
				'label' => __( 'Genral Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'infobox-style',
			[
				'label'      => __( 'Select Style', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'style-default',
				'options'    => [
					'style-default'          => __( 'Style 1', 'webvite' ),
					'style-border'          => __( 'Style 2', 'webvite' ),
					'style-flat'          => __( 'Style 3', 'webvite' ),
					'style-shadow'          => __( 'Style 4', 'webvite' ),
					'style-icon-bg'          => __( 'Style 5', 'webvite' ),				
				],
			]
		);

		$this->add_control(
			'shadow',
			[
				'label' => __( 'Infobox Shadow', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => ['infobox-style'=>['style-default','style-border','style-flat']],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'border-hover',
			[
				'label' => __( 'Border Hover', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'condition' => [
					'infobox-style'=>['style-default','style-border','style-flat'],
					'shadow'=>['yes']
				],
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'hover-bg-color',
			[
				'label' => __( 'Box Hover Background', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'infobox-style'=>['style-shadow'],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box.style-shadow:hover' => 'background: {{VALUE}};',
		 		],
			]
		);


		$this->add_responsive_control(
			'feature_padding',
			[
				'label' => __( 'Padding', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-default','style-border','style-flat'],
					'shadow'=>['yes']
				],
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-default','style-border','style-flat'],
					'shadow'=>['yes']
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'feature_padding2',
			[
				'label' => __( 'Padding', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-icon-bg'],
				],
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box.style-icon-bg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'border_radius-2',
			[
				'label' => __( 'Border Radius', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-icon-bg'],
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box.style-icon-bg' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'feature_padding_shadow',
			[
				'label' => __( 'Padding', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-shadow'],
				],
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'feature_shadow_radius',
			[
				'label' => __( 'Border Radius', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>['style-shadow'],
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __( 'Alignment', 'webvite' ),
				'type' => Controls_Manager::CHOOSE,
				'condition' => [
					'icon-position' => 'icon-top',
				],
				'options' => [
					'text-start' => [
						'title' => __( 'Left', 'webvite' ),
						'icon' => 'eicon-text-align-left',
					],
					'text-center' => [
						'title' => __( 'Center', 'webvite' ),
						'icon' => 'eicon-text-align-center',
					],
					'text-end' => [
						'title' => __( 'Right', 'webvite' ),
						'icon' => 'eicon-text-align-right',
					]
				]
			]
		);

		$this->add_control(
			'text-tablet',
			[
				'label' => __( 'Text Left Tablet', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => [
					'media-type' => 'icon',
					'icon-position' => 'icon-top',
				],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'text-mobile',
			[
				'label' => __( 'Text Left Mobile', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => [
					'media-type' => 'icon',
					'icon-position' => 'icon-top',
				],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->start_controls_tabs( 'accordion_icon_style' );

			$this->start_controls_tab(
				'infobox_bg_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
					'condition' => [
						'infobox-style'=>['style-icon-bg'],
					],
				)
			);

			$this->add_control(
				'infobox_bg_normal_color',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => [
						'infobox-style'=>['style-icon-bg'],
					],
					'selectors' => [
						'{{WRAPPER}} .feature-box.style-icon-bg' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'infobox_bg_hover',
				array(
					'label' => __( 'Hover', 'webvite' ),
					'condition' => [
						'infobox-style'=>['style-icon-bg'],
					],
				)
			);

			$this->add_control(
				'infobox_bg_hover_color',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => [
						'infobox-style'=>['style-icon-bg'],
					],
					'selectors' => [
						'{{WRAPPER}} .feature-box.style-icon-bg:after' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section(); 

		$this->start_controls_section(
			'title-setting',
			[
				'label' => __( 'Section Title', 'webvite' ),
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label' => __( 'Title Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .feature-box .title',
			]
		);

		$this->add_control(
			'title-tag',
			[
				'label'      => __( 'Title Tag', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'h4',
				'options'    => [
					'h2'          => __( 'h2', 'webvite' ),
					'h3'          => __( 'h3', 'webvite' ),
					'h4'          => __( 'h4', 'webvite' ),
					'h5'          => __( 'h5', 'webvite' ),
					'h6'          => __( 'h6', 'webvite' ),					
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Infobox Title', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
                'default' => __( 'Infobox Title', 'webvite' ),
			]
		);

		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-box .title' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_responsive_control(
			'title_space',
			[
				'label' => __( 'Title & Description Space', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box .title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'description-setting',
			[
				'label' => __( 'Section Description', 'webvite' ),
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'description-typography',
				'label' => __( 'Description Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .feature-box .feature-info p',
			]
		);

		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'webvite' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'webvite' ),
			]
		);

		$this->add_control(
			'description-color',
			[
				'label' => __( 'Description Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .feature-box .feature-info p' => 'color: {{VALUE}};',
		 		],
			]
		);
		
		$this->add_control(
			'infobox-link',
			[
				'label' => __( 'Link Enable', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'separator' => 'before',
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'link-typography',
				'label' => __( 'Link Typography', 'webvite' ),
				'condition' => ['infobox-link' => 'yes'],
				'selector' => '{{WRAPPER}} .feature-box .feature-link',
			]
		);
		
		$this->add_control(
			'button-text',
			[
				'label' => __( 'Button Text', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
				'default' => __( 'Read More', 'webvite' ),
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'webvite' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'webvite' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$this->add_control(
			'link-color',
			[
				'label' => __( 'Link Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'condition' => ['infobox-link' => 'yes'],
				'selectors' => [
					'{{WRAPPER}} .feature-box .feature-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .feature-box .feature-link:before' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'style-info',
			[
				'label' => __( 'Icon Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'media-type',
			[
				'label'      => __( 'Icon / Image', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon',
				'options'    => [
					'none'          => __( 'None', 'webvite' ),
					'icon'          => __( 'Icon', 'webvite' ),
					'image'          => __( 'Image', 'webvite' ),					
				]
			]
		);

		$this->add_control(
			'icon-position',
			[
				'label' => __( 'Icon Position', 'webvite' ),
				'type' => Controls_Manager::CHOOSE,
				'condition' => [
					'media-type' =>['icon','image'],
					'infobox-style'=>['style-default','style-border','style-flat','style-shadow'],
				],
				'default' => 'icon-top',
				'options' => [
					'icon-left' => [
						'title' => __( 'Left', 'webvite' ),
						'icon' => 'eicon-h-align-left',
					],
					'icon-top' => [
						'title' => __( 'Top', 'webvite' ),
						'icon' => 'eicon-v-align-top',
					],
					'icon-right' => [
						'title' => __( 'Right', 'webvite' ),
						'icon' => 'eicon-h-align-right',
					],
				],
			]
		);

		$this->add_control(
			'icon-animation',
			[
				'label' => __( 'Icon Hover Animation', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => [
					'media-type' => 'icon',
				],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'icon-tablet',
			[
				'label' => __( 'Icon Left Tablet', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => [
					'media-type' => 'icon',
					'icon-position' => 'icon-right',
				],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'icon-mobile',
			[
				'label' => __( 'Icon Left Mobile', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'condition' => [
					'media-type' => 'icon',
					'icon-position' => 'icon-right',
				],
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'webvite-icon',
			[
				'label' => __( 'Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition' => [
					'media-type' => 'icon',
				],
				'default' => [
					'value' => 'ti ti-home'
					
				]
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'webvite' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'media-type' => 'image',
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'media-type' => 'icon',
					'infobox-style'=>['style-default','style-border','style-shadow','style-icon-bg'],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box .feature-icon i' => 'color: {{VALUE}};',
					'{{WRAPPER}} .feature-box.style-icon-bg:after' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'media-type' => 'icon',
				],
				'default' => [
					'size' => 40,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box .feature-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_image_size',
			[
				'label' => __( 'Icon Size', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'media-type' => 'image',
				],
				'default' => [
					'size' => 70,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 200,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box .feature-icon img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_space',
			[
				'label' => __( 'Icon Space', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'condition' => [
					'media-type' =>['icon','image'],
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-box.icon-top .feature-icon' => 'margin-bottom: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .feature-box.icon-left .feature-icon' => 'margin-right: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .feature-box.icon-right .feature-icon' => 'margin-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_radius',
			[
				'label' => __( 'Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'condition' => [
					'infobox-style'=>[
						'style-border','style-flat'
					]
				],
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .feature-box.style-border .feature-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .feature-box.style-flat .feature-icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .feature-box .feature-icon img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs(
			'infobox-color-tabs',
			array(
				'condition' => [
					'infobox-style'=>['style-flat'],
				],
			)
		);

		$this->start_controls_tab(
			'infobox_color_normal',
			array(
				'label' => __( 'Normal', 'webvite' ),
			)
		);

		$this->add_control(
			'infobox_icon_color',
			array(
				'label'     => __( 'Icon Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .feature-box.style-flat .feature-icon i' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'infobox_icon_bg_color',
			array(
				'label'     => __( 'Icon Background', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .feature-box.style-flat .feature-icon i' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'infobox_color_hover',
			array(
				'label' => __( 'Hover', 'webvite' ),
			)
		);

		$this->add_control(
			'infobox_icon_hover_color',
			array(
				'label'     => __( 'Icon Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .feature-box.style-flat:hover .feature-icon i' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'infobox_icon_bg_hover_color',
			array(
				'label'     => __( 'Icon Background', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .feature-box.style-flat:hover .feature-icon i' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section(); 

		$this->end_controls_section(); 

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
				
		$media_html = '';

		if($settings['media-type'] == 'image')
		{
			if ( ! empty( $settings['image']['url'] ) ) 
			{
				$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
				$this->add_render_attribute( 'image', 'srcset', $settings['image']['url'] );
				$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
				$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
				$media_html = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
			}
			//$icon_html = sprintf('%1$s',esc_html($settings['image-style'],'webvite'));
		}
		if($settings['media-type'] == 'icon')
		{
			$media_html = sprintf('<i aria-hidden="true" class="%1$s"></i>',esc_attr($settings['webvite-icon']['value'],'webvite'));
			//$icon_html = sprintf('%1$s',esc_html($settings['icon-style'],'webvite'));
			//$icon_shap = sprintf('%1$s',esc_html($settings['icon-shap'],'webvite'));
		}

		$url = $settings['link']['url'];
		$this->add_render_attribute( 'infobox-class', 'class', esc_attr('feature-link read-more-link') ); 
		$this->add_render_attribute( 'infobox-class', 'href', esc_url($url) );
		
		$icon_position = sprintf('%1$s',esc_html($settings['icon-position'],'webvite'));

		$infobox_style = sprintf('%1$s',esc_html($settings['infobox-style'],'webvite'));

		$align = $settings['align'];
		if($settings['shadow'] == 'yes'){  $align .= ' shadow-enable'; } 
		if($settings['border-hover'] == 'yes'){  $align .= ' border-hover'; }
		if($settings['text-tablet'] == 'yes'){  $align .= ' tablet-text-left'; }
		if($settings['text-mobile'] == 'yes'){  $align .= ' mobile-text-left'; }
		if($settings['icon-tablet'] == 'yes'){  $align .= ' tablet-icon-left'; }
		if($settings['icon-mobile'] == 'yes'){  $align .= ' mobile-icon-left'; }
		if($settings['icon-animation'] == 'yes'){  $align .= ' icon-animation'; }
		
		//$color_type = sprintf('%1$s',esc_html($settings['color-type'],'webvite'));
		?>
		<div class="feature-box <?php echo $infobox_style; ?> <?php echo $icon_position; ?> <?php echo esc_attr($align);?>">
			<?php if($settings['media-type'] != 'none') { ?>
			<div class="feature-icon"><?php echo $media_html; ?></div>
			<?php } ?>
            <div class="feature-info">
				<?php if($settings['title']) { ?>
              		<<?php echo $settings['title-tag'];  ?> class="title"><?php echo sprintf('%1$s',esc_html($settings['title'],'webvite')); ?></<?php echo $settings['title-tag'];  ?>>
				<?php } if($settings['description']) { ?>
              		<p><?php echo sprintf('%1$s',esc_html($settings['description'],'webvite'));?></p>
				<?php } ?>
				<?php if($settings['infobox-link'] == 'yes') { ?>
				<a <?php echo $this->get_render_attribute_string( 'infobox-class' ) ?>>
					<?php echo sprintf('%1$s',esc_html($settings['button-text'],'webvite'));?>
					<i aria-hidden="true" class="ion ion-ios-arrow-thin-right"></i>
				</a>
				<?php } ?>
            </div>
        </div>
		<?php
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\info_box() );
?>