<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class webvite_newsletter extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'webvite_newsletter', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Newsletter', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the button widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'webvite' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'section',
			array(
				'label' => __( 'Newsletter', 'webvite' ),
			)
		);

		$this->add_control(
			'newsletter-style',
			array(
				'label'   => __( 'Newsletter Style', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'newsletter-style-1',
				'options' => array(
					'newsletter-style-1' => __( 'Style 1', 'webvite' ),
					'newsletter-style-2' => __( 'Style 2', 'webvite' ),
				),
			)
		);

		$this->add_control(
			'newsletter-button-position',
			array(
				'label'   => __( 'Button Position', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'button-right',
				'options' => array(
					'button-right' => __( 'Right', 'webvite' ),
					'button-bottom' => __( 'Bottom', 'webvite' ),
				),
			)
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'typography',
				'label'   => __( 'Button Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .newsletter-main .button-area button',
			)
		);

		$this->add_responsive_control(
			'button-space',
			[
				'label' => __( 'Button Space', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .newsletter-main.icon-outside.button-right .button-area' => 'margin-left: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .newsletter-main.newsletter-style-1.button-bottom .mc4wp-form-fields .button-area' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'webvite' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .newsletter-main .input-area input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .newsletter-main .button-area button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);



		$this->add_responsive_control(
			'newsletter_align',
			[
				'label' => __( 'Alignment', 'webvite' ),
				'type' => Controls_Manager::CHOOSE,
				'condition' => [
					'newsletter-button-position'=>['button-bottom'],
				],
				'default' => 'align-left',
				'options' => [
					'align-left'    => [
						'title' => __( 'Left', 'webvite' ),
						'icon' => 'eicon-text-align-left',
					],
					'align-center' => [
						'title' => __( 'Center', 'webvite' ),
						'icon' => 'eicon-text-align-center',
					],
					'align-right' => [
						'title' => __( 'Right', 'webvite' ),
						'icon' => 'eicon-text-align-right',
					],
					'align-justify' => [
						'title' => __( 'Justified', 'webvite' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
			]
		);

		$this->end_controls_section();

			$this->start_controls_section(
				'newsletter_color',
				[
					'label' => __( 'Newsletter Color', 'webvite' ),
					'tab' => Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_control(
				'input_text_color',
				[
					'label' 		=> __( 'Text Color', 'webvite' ),
					'type' 			=> Controls_Manager::COLOR,
					'default' 		=> '',
					'selectors' 	=> [
						'{{WRAPPER}} .newsletter-main .input-area input' => 'color: {{VALUE}};',
						'{{WRAPPER}} .newsletter-main .input-area input::placeholder' => 'color: {{VALUE}};',
						'{{WRAPPER}} .newsletter-main .input-area input:-ms-input-placeholder' => 'color: {{VALUE}};',
						'{{WRAPPER}} .newsletter-main .input-area input::-ms-input-placeholder' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'input_bg_color',
				[
					'label' 		=> __( 'Background Color', 'webvite' ),
					'type' 			=> Controls_Manager::COLOR,
					'default' 		=> '',
					'condition' => [
						'newsletter-style'=>['newsletter-style-1'],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .newsletter-main .input-area input' => 'background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'input_border_color',
				[
					'label' 		=> __( 'Border Color', 'webvite' ),
					'type' 			=> Controls_Manager::COLOR,
					'default' 		=> '',
					'condition' => [
						'newsletter-style'=>['newsletter-style-2'],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .newsletter-main .input-area input' => 'border-color: {{VALUE}};',
					],
				]
			);
			
			$this->start_controls_tabs( 'newsletter_button_color' );

			$this->start_controls_tab(
				'button_normal',
				[
					'label' => __( 'Normal', 'webvite' ),
				]
			);

			$this->add_control(
				'button_text_normal',
				[
					'label' => __( 'Text Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .newsletter-main .button-area button' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bg_normal',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .newsletter-main .button-area button' => 'background: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'button_hover',
				[
					'label' => __( 'Hover', 'webvite' ),
				]
			);

			$this->add_control(
				'button_text_hover',
				[
					'label' => __( 'Text Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .newsletter-main .button-area button:hover' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bg_hover',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .newsletter-main .button-area button:hover' => 'background: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_section();
	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$this->add_render_attribute( 'newsletter', 'class', 'newsletter-main' );
		$this->add_render_attribute( 'newsletter', 'class', $settings['newsletter-style'] );
		$this->add_render_attribute( 'newsletter', 'class', $settings['newsletter-button-position'] );
		$this->add_render_attribute( 'newsletter', 'class', $settings['newsletter_align'] );

		?>
		<div <?php echo $this->get_render_attribute_string( 'newsletter' ); ?>>
			<?php
			$webvite_opt = get_option( 'webvite_redux' );

			if ( isset( $webvite_opt['mailchimp_shortcode'] ) ) {
				$mailchimp_shortcode = $webvite_opt['mailchimp_shortcode'];
			}

			echo do_shortcode( $mailchimp_shortcode );
			?>
		</div>
		<?php
	}
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\webvite_newsletter() );
?>
