<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor portfolio grid widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class portfolio_fancy extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve portfolio grid widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'Portfolio Fancy', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve portfolio grid widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Portfolio Fancy', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the portfolio widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'webvite' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve portfolio widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register portfolio widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'section',
			array(
				'label' => __( 'General Setting', 'webvite' ),
			)
		);

		$this->add_control(
			'total-count',
			array(
				'label'       => __( 'Total Count', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
        );

		$this->add_control(
			'portfolio_grayscale',
			[
				'label' => __( 'Image Grayscale', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
        );

        $this->add_responsive_control(
			'portfolio_space',
			[
				'label' => __( 'portfolio Space', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-item-inner' => 'padding: {{SIZE}}{{UNIT}} 0;',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'color_setting',
			array(
				'label'     => __( 'Color Setting', 'webvite' ),
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'name-typography',
				'label'    => __( 'Name Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-title',
			)
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			array(
				'name'     => 'position-typography',
				'label'    => __( 'Position Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-category',
			)
		);

		$this->add_control(
			'position-color',
			array(
				'label'     => __( 'Position Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-category' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'link-color',
			array(
				'label'     => __( 'Link Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-control .popup-link' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'link-border-color',
			array(
				'label'     => __( 'Border Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item' => 'border-bottom-color: {{VALUE}};',
				),
			)
		);

		$this->start_controls_tabs(
			'portfolios_color-tabs',
		);

			$this->start_controls_tab(
				'portfolio_color_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'member-name',
				array(
					'label'     => __( 'Name Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-title a' => 'color: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'portfolio_color_hover',
				array(
					'label' => __( 'Hover', 'webvite' ),
				)
			);

			$this->add_control(
				'member-hover-name',
				array(
					'label'     => __( 'Name Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .portfolio-fancy .portfolio-fancy-item .portfolio-title a:hover' => 'color: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->end_controls_section();

	}
	/**
	 * Render portfolio widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$args = array(
			'post_type'        => 'portfolio',
			'post_status'      => 'publish',
			'posts_per_page'   => $settings['total-count'],
			'numberposts'      => -1,
			'suppress_filters' => 0,
		);

		$the_query = new \WP_Query( $args );

		global $post;

		$this->add_render_attribute( 'portfolio', 'class', 'portfolio-fancy' );

        $this->add_render_attribute( 'portfolio-class', 'class', 'portfolio-member' );

		if($settings['portfolio_grayscale'] == 'yes') {
				$this->add_render_attribute( 'portfolio', 'class', 'portfolio-grayscale' ); 
			}

		?>			
		<div <?php echo $this->get_render_attribute_string( 'portfolio' ); ?>>
			<?php
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				$portfolio_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'webvite_500x650' );
				$term_list = wp_get_post_terms( get_the_ID(), 'portfolio-categories' );
				$slugs     = array();
				foreach ( $term_list as $term ) {
					$slugs[] = $term->slug;
				}
				?>
				<div class="portfolio-fancy-item">
					<div class="portfolio-item-inner">
					<div class="portfolio-info">
						<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
						<h6 class="portfolio-category"><?php echo $term->name; ?></h6>
					</div>
					<?php if ( has_post_thumbnail() ) { ?>
					<div class="portfolio-img">
						<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design"> 
					</div>
					<?php } ?>
					<div class="portfolio-control"><a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-top-right"></i></a></div>
					</div>
				</div>
				<?php
			}
			wp_reset_postdata();
			?>
		</div>

		<?php
	}

}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\portfolio_fancy() );
?>
