<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Elementor portfolio widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class portfolio extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve testimonial widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'Portfolio', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve testimonial widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */

	public function get_title() {
		return __( 'Portfolio', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the testimonial widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return array( 'webvite' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve testimonial widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register testimonial widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {

		$this->start_controls_section(
			'section',
			array(
				'label' => __( 'Genral Setting', 'webvite' ),
			)
		);

		$this->add_control(
			'portfolio-type',
			array(
				'label'   => __( 'Portfolio Type', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'type-grid',
				'options' => array(
					'type-grid' => __( 'Grid', 'webvite' ),
					'type-masonry' => __( 'Masonry', 'webvite' ),
					'type-slider' => __( 'Slider', 'webvite' ),					
				),
			)
		);

		$this->add_control(
			'portfolio-style',
			array(
				'label'   => __( 'Portfolio Style', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'portfolio-style-1',
				'options' => array(
					'portfolio-style-1' => __( 'Style 1', 'webvite' ),
					'portfolio-style-2' => __( 'Style 2', 'webvite' ),
					'portfolio-style-3' => __( 'Style 3', 'webvite' ),
				),
			)
		);

		$this->add_control(
			'image-size',
			array(
				'label'   => __( 'Portfolio Image Size', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'full',
				'options' => array(
					'full' => __( 'Default', 'webvite' ),
					'webvite_500x500' => __( '500 x 500', 'webvite' ),
					'webvite_500x400' => __( '500 x 400', 'webvite' ),
					'webvite_500x650' => __( '500 x 650', 'webvite' ),
				),
			)
		);

		$this->add_control(
			'filter',
			array(
				'label'   => __( 'Filter', 'webvite' ),
				'type'    => Controls_Manager::SWITCHER,
				'condition' => array(
					'portfolio-type' => array( 'type-grid','type-masonry' ),
				),
				'default' => 'yes',
				'yes'     => __( 'yes', 'webvite' ),
				'no'      => __( 'no', 'webvite' ),
			)
		);

		$this->add_control(
			'filter-style',
			array(
				'label'   => __( 'Filter Style', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'filter-style-1',
				'condition' => array(
					'portfolio-type' => array( 'type-grid','type-masonry' ),
				),
				'options' => array(
					'filter-style-1' => __( 'Style 1', 'webvite' ),
					'filter-style-2' => __( 'Style 2', 'webvite' ),
					'filter-style-3' => __( 'Style 3', 'webvite' ),
				),
			)
		);

		$this->add_control(
			'total-count',
			array(
				'label'       => __( 'Total Count', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'grid_setting',
			array(
				'label'     => __( 'Column Setting', 'webvite' ),
				'condition' => array(
					'portfolio-type' => array( 'type-grid','type-masonry' ),
				),
			)
		);
        
        $this->add_control(
			'grid-desk',
			array(
				'label'     => __( 'Desktop view', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'desk-grid-4',
				'options'   => array(
					'desk-grid-2' => __( '2 Column', 'webvite' ),
					'desk-grid-3' => __( '3 Column', 'webvite' ),
					'desk-grid-4' => __( '4 Column', 'webvite' ),
					'desk-grid-5' => __( '5 Column', 'webvite' ),
				),
			)
        );
        
        $this->add_control(
			'grid-lap',
			array(
				'label'     => __( 'Laptop view', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'lap-grid-3',
				'options'   => array(
					'lap-grid-2' => __( '2 Column', 'webvite' ),
					'lap-grid-3' => __( '3 Column', 'webvite' ),
					'lap-grid-4' => __( '4 Column', 'webvite' ),
				),
			)
        );

        $this->add_control(
			'grid-tab',
			array(
				'label'     => __( 'Tablet view', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'tab-grid-3',
				'options'   => array(
					'tab-grid-2' => __( '2 Column', 'webvite' ),
					'tab-grid-3' => __( '3 Column', 'webvite' ),
					'tab-grid-4' => __( '4 Column', 'webvite' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mobile',
			array(
				'label'     => __( 'Mobile view', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mob-grid-2',
				'options'   => array(
                    'mob-grid-1' => __( '1 Column', 'webvite' ),
                    'mob-grid-2' => __( '2 Column', 'webvite' ),
					'mob-grid-3' => __( '3 Column', 'webvite' ),
				),
			)
        );
        
        $this->add_control(
			'grid-mportal',
			array(
				'label'     => __( 'Mobile Portal view', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'mpor-grid-1',
				'options'   => array(
                    'mpor-grid-1' => __( '1 Column', 'webvite' ),
                    'mpor-grid-2' => __( '2 Column', 'webvite' ),
				),
			)
		);
        
		$this->add_control(
			'grid-space',
			array(
				'label'     => __( 'Margin', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'grid-space-30',
				'options'   => array(
		            'grid-space-0' => __( '0', 'webvite' ),
		            'grid-space-10' => __( '10', 'webvite' ),
		            'grid-space-20' => __( '20', 'webvite' ),
		            'grid-space-30' => __( '30', 'webvite' ),
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_setting',
			array(
				'label'     => __( 'Slider Setting', 'webvite' ),
				'condition' => array(
					'portfolio-type' => array( 'type-slider' ),
				),
			)
		);

		$this->add_control(
			'slider-desk',
			array(
				'label'       => __( 'Desktop view', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
			)
		);

		$this->add_control(
			'slider-laptop',
			array(
				'label'       => __( 'Laptop view', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '4',
			)
		);

		$this->add_control(
			'slider-tab',
			array(
				'label'       => __( 'Tablet view', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '3',
			)
		);

		$this->add_control(
			'slider-mobile',
			array(
				'label'       => __( 'Mobile view', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '2',
			)
		);

		$this->add_control(
			'slider-mobile-portal',
			array(
				'label'       => __( 'Mobile Portal View', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => array(
					'active' => true,
				),
				'label_block' => true,
				'default'     => '1',
			)
		);

		$this->add_control(
			'autoplay',
			array(
				'label'   => __( 'Autoplay', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'webvite' ),
					'false' => __( 'False', 'webvite' ),

				),
			)
		);

		$this->add_control(
			'loop',
			array(
				'label'   => __( 'Loop', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'webvite' ),
					'false' => __( 'False', 'webvite' ),

				),
			)
		);

		$this->add_control(
			'slider-dots',
			array(
				'label'   => __( 'Dots', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'webvite' ),
					'false' => __( 'False', 'webvite' ),

				),
			)
		);

		$this->add_control(
			'slider-arrow',
			array(
				'label'   => __( 'Arrow', 'webvite' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'true',
				'options' => array(
					'true'  => __( 'True', 'webvite' ),
					'false' => __( 'False', 'webvite' ),

				),
			)
		);

		$this->add_control(
			'arrow-style',
			array(
				'label'     => __( 'Arrow Style', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => array(
					'slider-arrow' => array( 'true' ),
				),
				'default'   => 'arrow-default',
				'options'   => array(
					'arrow-default' => __( 'Default', 'webvite' ),
					'arrow-style2'  => __( 'Style 2', 'webvite' ),
					'arrow-style3'  => __( 'Style 3', 'webvite' ),
				),
			)
		);

		$this->add_responsive_control(
			'slider-data-space',
			array(
				'label' => __( 'Margin', 'elementor' ),
				'type'  => Controls_Manager::SLIDER,
				'condition' => array(
					'portfolio-type' => array( 'type-slider' ),
				),
			)
		);

		$this->add_control(
			'slider-space',
			array(
				'label'     => __( 'Margin', 'webvite' ),
				'type'      => Controls_Manager::SELECT,
				'condition' => array(
					'portfolio-type' => array( 'type-grid','type-masonry' ),
				),
				'default'   => 'slider-space-15',
				'options'   => array(
		            'slider-space-0' => __( 'Space 0', 'webvite' ),
		            'slider-space-5' => __( 'Space 5', 'webvite' ),
		            'slider-space-10' => __( 'Space 10', 'webvite' ),
		            'slider-space-15' => __( 'Space 15', 'webvite' ),
		            'slider-space-20' => __( 'Space 20', 'webvite' ),
		            'slider-space-25' => __( 'Space 25', 'webvite' ),
		            'slider-space-30' => __( 'Space 30', 'webvite' ),
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_color',
			[
				'label' => __( 'Filter Color', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => array(
					'filter' => array( 'yes' ),
				),
			]
		);
		
			$this->start_controls_tabs( 'filter_color_style' );

			$this->start_controls_tab(
				'filter_button_normal',
				[
					'label' => __( 'Normal', 'webvite' ),
				]
			);

			$this->add_control(
				'filter_text_normal',
				[
					'label' => __( 'Text Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter li a' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'filter_bg_normal',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => array(
						'portfolio-style' => array('portfolio-style-1'),
					),
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-1 li a' => 'background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'filter_border_normal',
				[
					'label' => __( 'Border Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => array(
						'portfolio-style' => array('portfolio-style-2','portfolio-style-3'),
					),
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-2 li a' => 'border-bottom-color: {{VALUE}};',
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-3 li a' => 'border-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'filter_button_active',
				[
					'label' => __( 'Active', 'webvite' ),
				]
			);

			$this->add_control(
				'filter_text_active',
				[
					'label' => __( 'Text Active Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter li.current a' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'filter_bg_active',
				[
					'label' => __( 'Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => array(
						'portfolio-style' => array('portfolio-style-1'),
					),
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-1 li.current a' => 'background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'filter_border_active',
				[
					'label' => __( 'Border Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'condition' => array(
						'portfolio-style' => array('portfolio-style-2','portfolio-style-3'),
					),
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-2 li.current a' => 'border-bottom-color: {{VALUE}};',
						'{{WRAPPER}} .portfolio-main .b-isotope-filter.filter-style-3 li.current a' => 'border-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_section();

		$this->start_controls_section(
			'portfolio_color',
			array(
				'label' => __( 'Portfolio Color', 'webvite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'portfolio_background_color',
			array(
				'label'     => __( 'Background Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'portfolio-style' => array('portfolio-style-2','portfolio-style-3'),
				),
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-2 .grid-item .item-info' => 'background: {{VALUE}};',
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .grid-item .item-info' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			array(
				'name'      => 'portfolio_gradiant-bg-color',
				'label'     => __( 'Background Color', 'webvite' ),
				'types'     => array( 'gradient' ),
				'condition' => array(
					'portfolio-style' => array('portfolio-style-2','portfolio-style-3'),
				),
				'selector'  => '{{WRAPPER}} .portfolio-main .portfolio-style-2 .grid-item .item-info,
								{{WRAPPER}} .portfolio-main .portfolio-style-3 .grid-item .item-info',
			)
		);

		$this->add_control(
			'portfolio_link_color',
			array(
				'label'     => __( 'Icon Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'condition' => array(
					'portfolio-style' => array('portfolio-style-2','portfolio-style-3'),
				),
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-2 .item-info .popup-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .item-info .popup-link' => 'color: {{VALUE}};',
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .portfolio-item .popup-link' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'portfolio_link_hover_bg',
			array(
				'label'     => __( 'Icon Hover Background', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'separator' => 'before',
				'condition' => array(
					'portfolio-style' => array( 'portfolio-style-3' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .item-info .popup-link:hover' => 'background: {{VALUE}};',
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .portfolio-item .popup-link:hover' => 'border-color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'portfolio_link_hover_color',
			array(
				'label'     => __( 'Icon Hover Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => array(
					'portfolio-style' => array( 'portfolio-style-3' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-3 .item-info .popup-link:hover' => 'color: {{VALUE}};',
				),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'portfolio_info',
			array(
				'label' => __( 'Portfolio Info', 'webvite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'name-typography',
				'label'   => __( 'Name Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .portfolio-main .item-info .portfolio-title',
			]
		);

		$this->add_control(
			'portfolio_name_color',
			array(
				'label'     => __( 'Name Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-1 .item-info .portfolio-title' => 'color: {{VALUE}};',
					'{{WRAPPER}} .portfolio-main .grid-item .item-info .portfolio-title .title-link' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'portfolio_name_bg',
			array(
				'label'     => __( 'Name Background', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'separator' => 'after',
				'condition' => array(
					'portfolio-style' => array( 'portfolio-style-1' ),
				),
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-1 .item-info .portfolio-title' => 'background: {{VALUE}};',
				),
			)
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'category-typography',
				'label'   => __( 'Category Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .portfolio-main .item-info .portfolio-category',
			]
		);

		$this->add_control(
			'portfolio_category_color',
			array(
				'label'     => __( 'Category Color', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .grid-item .item-info .portfolio-category' => 'color: {{VALUE}};',
				),
			)
		);

		$this->add_control(
			'portfolio_category_bg',
			array(
				'label'     => __( 'Category Background', 'webvite' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => array(
					'portfolio-style' => array( 'portfolio-style-1' ),
				),
				'default'   => '',
				'selectors' => array(
					'{{WRAPPER}} .portfolio-main .portfolio-style-1 .item-info .portfolio-category' => 'background: {{VALUE}};',
				),
			)
		);

		$this->end_controls_section();

	}
	/**
	 * Render testimonial widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function render() {

		$settings = $this->get_settings();

		$args = array(
			'post_type'        => 'portfolio',
			'post_status'      => 'publish',
			'posts_per_page'   => $settings['total-count'],
			'numberposts'      => -1,
			'suppress_filters' => 0,
		);

		$the_query = new \WP_Query( $args );

		global $post;

		$portfolio_style = sprintf( '%1$s', esc_html( $settings['portfolio-style'], 'webvite' ) );
		$image_size = sprintf( '%1$s', esc_html( $settings['image-size'], 'webvite' ) );
		?>
		
		<?php if ( $settings['portfolio-type'] === 'type-grid' ) {
			$this->add_render_attribute( 'portfolio-grid', 'class', 'portfolio-main type-grid' );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-desk'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-lap'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-tab'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-mobile'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-mportal'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-space'] );
		 ?>
			<div <?php echo $this->get_render_attribute_string( 'portfolio-grid' ); ?>>
				<div class="b-isotope portfolio-wrapper <?php echo $portfolio_style; ?> portfolio-column-3">
				<?php 
				if ( $settings['filter'] == 'yes' ) {
				$filter_style = sprintf( '%1$s', esc_html( $settings['filter-style'], 'webvite' ) );
				 ?>
				<ul class="b-isotope-filter clearfix <?php echo $filter_style; ?>">
					<?php $terms = get_terms( array( 'taxonomy' => 'portfolio-categories' ) ); ?>
				<li class="current"><a href="" data-filter="*">All</a></li>
					<?php foreach ( $terms as $term ) { ?>
				<li><a href="" data-filter=".<?php echo $term->slug; ?>"><?php echo $term->name; ?></a></li>
				<?php } ?>
				</ul>
				<?php } ?>
				<ul class="b-isotope-grid grid list-unstyled">
					<li class="grid-sizer"></li>
					<?php
					while ( $the_query->have_posts() ) {
						$the_query->the_post();
						$term_list = wp_get_post_terms( get_the_ID(), 'portfolio-categories' );
						$slugs     = array();
						foreach ( $term_list as $term ) {
							$slugs[] = $term->slug;
						}
						$portfolio_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), ''. $image_size .'' );
						?>
						<?php if ( $settings['portfolio-style'] === 'portfolio-style-1' ) { ?>
							<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
							<div class="portfolio-item">
								<div class="item-img">
									<a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /></a> 
								</div>
								<div class="item-info">
									<h3 class="portfolio-title"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></h3>
									<span class="portfolio-category"><?php echo $term->name; ?></span> 
								</div>
							</div>
							</li>
						<?php } ?>
						<?php if ( $settings['portfolio-style'] === 'portfolio-style-2' ) { ?>
						<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
						<div class="portfolio-item">
							<div class="item-img">
								<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /> 
							</div>
							<div class="item-info">
								<div class="info-inner">
									<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
									<span class="portfolio-category"><?php echo $term->name; ?></span>
								</div>
								<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
							</div>
						</div>
					</li>
					<?php } ?>
					<?php if ( $settings['portfolio-style'] === 'portfolio-style-3' ) { ?>
						<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
						<div class="portfolio-item">
							<div class="item-img">
								<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /> 
								<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
							</div>
							<div class="item-info">
								<div class="info-inner">
									<span class="portfolio-category"><?php echo $term->name; ?></span>
									<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
								</div>
							</div>
						</div>
					</li>
					<?php } ?>
						<?php
					}
					wp_reset_postdata();
					?>
				</ul>
				</div>
			</div>
		<?php } ?>
		<?php if ( $settings['portfolio-type'] === 'type-masonry' ) {
			$this->add_render_attribute( 'portfolio-grid', 'class', 'portfolio-main type-masonry' );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-desk'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-lap'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-tab'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-mobile'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-mportal'] );
			$this->add_render_attribute( 'portfolio-grid', 'class', $settings['grid-space'] );
		 ?>
			<div <?php echo $this->get_render_attribute_string( 'portfolio-grid' ); ?>>
				<div class="b-isotope portfolio-wrapper <?php echo $portfolio_style; ?> portfolio-column-3">
				<?php 
				if ( $settings['filter'] == 'yes' ) {
				$filter_style = sprintf( '%1$s', esc_html( $settings['filter-style'], 'webvite' ) );
				 ?>
				<ul class="b-isotope-filter clearfix <?php echo $filter_style; ?>">
					<?php $terms = get_terms( array( 'taxonomy' => 'portfolio-categories' ) ); ?>
				<li class="current"><a href="" data-filter="*">All</a></li>
					<?php foreach ( $terms as $term ) { ?>
				<li><a href="" data-filter=".<?php echo $term->slug; ?>"><?php echo $term->name; ?></a></li>
				<?php } ?>
				</ul>
				<?php } ?>
				<ul class="b-isotope-grid grid list-unstyled">
					<li class="grid-sizer"></li>
					<?php
					while ( $the_query->have_posts() ) {
						$the_query->the_post();
						$term_list = wp_get_post_terms( get_the_ID(), 'portfolio-categories' );
						$slugs     = array();
						foreach ( $term_list as $term ) {
							$slugs[] = $term->slug;
						}
						
						$portfolio_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), ''. $image_size .'' );
						?>
						<?php if ( $settings['portfolio-style'] === 'portfolio-style-1' ) { ?>
							<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
							<div class="portfolio-item">
								<div class="item-img">
									<a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /></a> 
								</div>
								<div class="item-info">
									<h3 class="portfolio-title"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></h3>
									<span class="portfolio-category"><?php echo $term->name; ?></span> 
								</div>
							</div>
							</li>
						<?php } ?>
						<?php if ( $settings['portfolio-style'] === 'portfolio-style-2' ) { ?>
						<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
						<div class="portfolio-item">
							<div class="item-img">
								<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /> 
							</div>
							<div class="item-info">
								<div class="info-inner">
									<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
									<span class="portfolio-category"><?php echo $term->name; ?></span>
								</div>
								<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
							</div>
						</div>
					</li>
					<?php } ?>
					<?php if ( $settings['portfolio-style'] === 'portfolio-style-3' ) { ?>
						<li class="grid-item <?php echo implode( ' ', $slugs ); ?>">
						<div class="portfolio-item">
							<div class="item-img">
								<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" />
								<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
							</div>
							<div class="item-info">
								<div class="info-inner">
									<span class="portfolio-category"><?php echo $term->name; ?></span>
									<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
								</div>
							</div>
						</div>
					</li>
					<?php } ?>
						<?php
					}
					wp_reset_postdata();
					?>
				</ul>
				</div>
			</div>
		<?php } ?>
		<?php if ( $settings['portfolio-type'] === 'type-slider' ) { 

				$arrow_style = sprintf( '%1$s', esc_html( $settings['arrow-style'], 'webvite' ) );
				
				$this->add_render_attribute( 'portfolio-slider', 'class', 'portfolio-slider swiper-container' );
				$this->add_render_attribute( 'portfolio-slider', 'data-items', $settings['slider-desk'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-lg-items', $settings['slider-laptop'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-md-items', $settings['slider-tab'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-sm-items', $settings['slider-mobile'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-xs-items', $settings['slider-mobile-portal'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-space', $settings['slider-data-space']['size'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-arrow', $settings['slider-arrow'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-bullets', $settings['slider-dots'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-autoplay', $settings['autoplay'] );
				$this->add_render_attribute( 'portfolio-slider', 'data-loop', $settings['loop'] );
				?>
			<div class="portfolio-main type-slider <?php echo $arrow_style; ?>">
				<div class="b-isotope portfolio-wrapper <?php echo $portfolio_style; ?> portfolio-column-3">
					<div <?php echo $this->get_render_attribute_string( 'portfolio-slider' ); ?>>
						<div class="swiper-wrapper">						
							<?php
							while ( $the_query->have_posts() ) {
								$the_query->the_post();
								$term_list = wp_get_post_terms( get_the_ID(), 'portfolio-categories' );
								$slugs     = array();
								foreach ( $term_list as $term ) {
									$slugs[] = $term->slug;
								}								
								$portfolio_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), ''. $image_size .'' );								
								?>
								<div class="swiper-slide grid-item">
									<?php if ( $settings['portfolio-style'] === 'portfolio-style-1' ) { ?>
									<div class="portfolio-item">
										<div class="item-img">
											<a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /></a> 
										</div>
										<div class="item-info">
											<h3 class="portfolio-title"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></h3>
											<span class="portfolio-category"><?php echo $term->name; ?></span> 
										</div>
									</div>
									<?php } ?>
									<?php if ( $settings['portfolio-style'] === 'portfolio-style-2' ) { ?>
										<div class="portfolio-item">
										<div class="item-img">
											<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" /> 
										</div>
										<div class="item-info">
										<div class="info-inner">
												<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
												<span class="portfolio-category"><?php echo $term->name; ?></span>
											</div>
											<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
										</div>
									</div>
									<?php } ?>
									<?php if ( $settings['portfolio-style'] === 'portfolio-style-3' ) { ?>
										<div class="portfolio-item">
										<div class="item-img">
											<img src="<?php echo esc_url( $portfolio_image[0] ); ?>" alt="Design" />
											<a class="popup-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><i class="ti ti-arrow-right"></i></a>
										</div>
										<div class="item-info">
										<div class="info-inner">
												<span class="portfolio-category"><?php echo $term->name; ?></span>
												<h3 class="portfolio-title"><a class="title-link" href="<?php echo esc_url( get_permalink( $the_query->ID ) ); ?>"><?php echo sprintf( '%s', esc_html( get_the_title( $post->ID ), 'webvite' ) ); ?></a></h3>
											</div>
										</div>
									</div>
									<?php } ?>
								</div>
								<?php
							}
							wp_reset_postdata();
							?>
						</div>
					
						<div class="swiper-pagination"></div>
						<div class="swiper-button-next"><i class="fas fa-chevron-right"></i></div>
						<div class="swiper-button-prev"><i class="fas fa-chevron-left"></i></div>
					
					</div>

				</div>
			</div>										
		<?php } ?>
		<script>
			jQuery('.swiper-container' ).each(function () {
				var swiper = new Swiper( jQuery( this ), {
				slidesPerView:  ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),
				spaceBetween:   ((jQuery(this).attr('data-space')) ? jQuery(this).data('space') : 15),
				autoplay:       ((jQuery(this).attr('data-autoplay')) ? jQuery(this).data('autoplay') : false),
				loop:           ((jQuery(this).attr('data-loop')) ? jQuery(this).data('loop') : false),
				navigation: {
					nextEl: '.swiper-button-next',
					prevEl: '.swiper-button-prev',
				},
				pagination: {
					el: '.swiper-pagination',
					clickable: true,
				},
				breakpoints: {
					1200: {slidesPerView: ((jQuery(this).attr('data-items')) ? jQuery(this).attr('data-items') : 4),},
					992:  {slidesPerView: ((jQuery(this).attr('data-lg-items')) ? jQuery(this).attr('data-lg-items') : 3),},
					768:  {slidesPerView: ((jQuery(this).attr('data-md-items')) ? jQuery(this).attr('data-md-items') : 2),},
					480:  {slidesPerView: ((jQuery(this).attr('data-sm-items')) ? jQuery(this).attr('data-sm-items') : 1),},
					0:  {slidesPerView: ((jQuery(this).attr('data-xs-items')) ? jQuery(this).attr('data-xs-items') : 1),}
				}
				});
			});
		</script>
		<?php
	}

}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\portfolio() );
?>
