<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class service_box extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve service_box widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'service_box', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve service_box widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Service Box', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the service_box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve service_box widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register service_box widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'genral-setting',
			[
				'label' => __( 'Genral Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'service-box-style',
			[
				'label'      => __( 'Select Style', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'services-style-1',
				'options'    => [
					'services-style-1'          => __( 'Style 1', 'webvite' ),
					'services-style-2'          => __( 'Style 2', 'webvite' ),
					'services-style-3'          => __( 'Style 3', 'webvite' ),			
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'webvite' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'title-setting',
			[
				'label' => __( 'Section Title', 'webvite' ),
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label' => __( 'Title Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .feature-box .title',
			]
		);

		$this->add_control(
			'title-tag',
			[
				'label'      => __( 'Title Tag', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'h5',
				'options'    => [
					'h2'          => __( 'h2', 'webvite' ),
					'h3'          => __( 'h3', 'webvite' ),
					'h4'          => __( 'h4', 'webvite' ),
					'h5'          => __( 'h5', 'webvite' ),
					'h6'          => __( 'h6', 'webvite' ),					
				],
			]
		);
		
		$this->add_control(
			'title',
			[
				'label' => __( 'Infobox Title', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
                'default' => __( 'Infobox Title', 'webvite' ),
			]
		);

		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-box .services-box-info .services-box-title' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_responsive_control(
			'title_space',
			[
				'label' => __( 'Title & Description Space', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .services-box .services-box-info .services-box-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'description-setting',
			[
				'label' => __( 'Section Description', 'webvite' ),
			]
		);

		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'webvite' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'webvite' ),
			]
		);

		$this->add_control(
			'description-color',
			[
				'label' => __( 'Description Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-box .services-box-info .services-box-content' => 'color: {{VALUE}};',
		 		],
			]
		);
		
		$this->add_control(
			'infobox-link',
			[
				'label' => __( 'Link Enable', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'link-typography',
				'label' => __( 'Link Typography', 'webvite' ),
				'condition' => ['infobox-link' => 'yes'],
				'selector' => '{{WRAPPER}} .feature-box .feature-link',
			]
		);
		
		$this->add_control(
			'button-text',
			[
				'label' => __( 'Button Text', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
				'default' => __( 'Read More', 'webvite' ),
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'webvite' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'webvite' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'style-info',
			[
				'label' => __( 'Icon Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'webvite-icon',
			[
				'label' => __( 'Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'ti ti-settings'
					
				]
			]
		);

		$this->add_control(
			'icon-color',
			[
				'label' => __( 'Icon Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .services-box .services-box-icon i' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'icon-bg-color',
			[
				'label' => __( 'Icon Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'service-box-style'=>['services-style-2','services-style-3'],
				],
				'selectors' => [
					'{{WRAPPER}} .services-box.services-style-2 .services-box-icon' => 'background: {{VALUE}};',
					'{{WRAPPER}} .services-box.services-style-3 .services-box-icon' => 'background: {{VALUE}};',
					'{{WRAPPER}} .services-box.services-style-3 .services-box-icon:before' => 'border-right-color: {{VALUE}} !important;',
					'{{WRAPPER}} .services-box.services-style-3 .services-box-icon:after' => 'border-left-color: {{VALUE}} !important;',
		 		],
			]
		);

		$this->end_controls_section(); 

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
		
		$service_box_style = sprintf('%1$s',esc_html($settings['service-box-style'],'webvite'));
		
		if ( ! empty( $settings['image']['url'] ) ) 
		{
			$this->add_render_attribute( 'image', 'src', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'srcset', $settings['image']['url'] );
			$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $settings['image'] ) );
			$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $settings['image'] ) );
			$media_image = Group_Control_Image_Size::get_attachment_image_html( $settings, 'thumbnail', 'image' );
		}
	
	
		$media_icon = sprintf('<i aria-hidden="true" class="%1$s"></i>',esc_attr($settings['webvite-icon']['value'],'webvite'));
	

		$url = $settings['link']['url'];
		$this->add_render_attribute( 'infobox-class', 'class', esc_attr('feature-link read-more-link') ); 
		$this->add_render_attribute( 'infobox-class', 'href', esc_url($url) );
				
		$color_type = sprintf('%1$s',esc_html($settings['color-type'],'webvite'));

		if ( $settings['service-box-style'] === 'services-style-1' ) {
			?>
			<div class="services-box <?php echo $service_box_style; ?>">
				<div class="services-box-inner">
					<div class="services-box-img">
						<div class="services-img"><?php echo $media_image; ?></div>
					</div>
					<div class="services-box-info">
					<div class="services-info-inner">
						<span class="services-box-icon"><?php echo $media_icon; ?></span>
						<?php if($settings['title']) { ?>
						<<?php echo $settings['title-tag'];  ?> class="services-box-title"><?php echo sprintf('%1$s',esc_html($settings['title'],'webvite')); ?></<?php echo $settings['title-tag'];  ?>>
						<?php } if($settings['description']) { ?>
						<div class="services-box-content"><?php echo sprintf('%1$s',esc_html($settings['description'],'webvite'));?></div>
						<?php } ?>
						<div class="services-link">
							<a <?php echo $this->get_render_attribute_string( 'infobox-class' ) ?>>
								<span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'webvite'));?></span>
								<i class="ion ion-ios-arrow-thin-right"></i>
							</a>
						</div>
					</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( $settings['service-box-style'] === 'services-style-2' ) {
			?>
			<div class="services-box <?php echo $service_box_style; ?>">
				<div class="services-box-inner">
					<div class="services-box-img">
						<div class="services-img"><?php echo $media_image; ?></div>
						<span class="services-box-icon"><?php echo $media_icon; ?></span>
					</div>
					<div class="services-box-info">
						<div class="services-info-inner">
							<?php if($settings['title']) { ?>
							<<?php echo $settings['title-tag'];  ?> class="services-box-title"><?php echo sprintf('%1$s',esc_html($settings['title'],'webvite')); ?></<?php echo $settings['title-tag'];  ?>>
							<?php } if($settings['description']) { ?>
							<div class="services-box-content"><?php echo sprintf('%1$s',esc_html($settings['description'],'webvite'));?></div>
							<?php } ?>
							<?php if($settings['infobox-link'] == 'yes') { ?>
							<div class="services-link">
								<a <?php echo $this->get_render_attribute_string( 'infobox-class' ) ?>>
									<span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'webvite'));?></span>
									<i class="ion ion-ios-arrow-thin-right"></i>
								</a>
							</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
		if ( $settings['service-box-style'] === 'services-style-3' ) {
			?>
			<div class="services-box <?php echo $service_box_style; ?>">
				<div class="services-box-inner">
					<div class="services-box-img">
						<div class="services-img"><?php echo $media_image; ?></div>
						<span class="services-box-icon"><?php echo $media_icon; ?></span>
					</div>
					<div class="services-box-info">
						<div class="services-info-inner">
							<?php if($settings['title']) { ?>
							<<?php echo $settings['title-tag'];  ?> class="services-box-title"><?php echo sprintf('%1$s',esc_html($settings['title'],'webvite')); ?></<?php echo $settings['title-tag'];  ?>>
							<?php } if($settings['description']) { ?>
							<div class="services-box-content"><?php echo sprintf('%1$s',esc_html($settings['description'],'webvite'));?></div>
							<?php } ?>
							<?php if($settings['infobox-link'] == 'yes') { ?>
							<div class="services-link">
								<a <?php echo $this->get_render_attribute_string( 'infobox-class' ) ?>>
									<span><?php echo sprintf('%1$s',esc_html($settings['button-text'],'webvite'));?></span>
									<i class="ion ion-ios-arrow-thin-right"></i>
								</a>
							</div>
							<?php } ?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\service_box() );
?>