<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class service_slider extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve service_slider widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'service_slider', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve service_slider widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Service Slider', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the service_slider widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve service_slider widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register service_slider widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'title-setting',
			[
				'label' => __( 'Section Title', 'webvite' ),
			]
		);

		$this->add_control(
			'sub-title-show',
			[
				'label' => __( 'Sub Section Title', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$this->add_control(
			'sub-title',
			[
				'label' => __( 'Service Sub Title', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
                'default' => __( 'Service Sub Title', 'webvite' ),
				'condition' => ['sub-title-show' => 'yes']
			]
		);

		$this->add_control(
			'sub-title-color',
			[
				'label' => __( 'Sub Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'separator'   => 'after',
				'condition' => ['sub-title-show' => 'yes'],
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .section-title .title-tagline' => 'color: {{VALUE}};',
					'{{WRAPPER}} .ps-services-slider .section-title .title-tagline:before' => 'border-bottom-color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Service Title', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
                'default' => __( 'Service Title', 'webvite' ),
			]
		);
		
		$this->add_control(
			'title_html_tag',
			[
				'label' => __( 'Title HTML Tag', 'webvite' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
				],
				'default' => 'h6',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label'   => __( 'Title Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .ps-services-slider .section-title .main-title',
			]
		);

		$this->add_control(
			'title-color',
			[
				'label' => __( 'Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .section-title .main-title' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'slider-items-setting',
			[
				'label' => __( 'Slider Items', 'webvite' ),
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			array(
				'label'     => __( 'Choose Image', 'webvite' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => array(
					'active' => true,
				),
				'default'   => array(
					'url' => Utils::get_placeholder_image_src(),
				),
			)
		);

		$repeater->add_control(
			'webvite-icon',
			array(
				'label'            => __( 'Icon', 'webvite' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default'          => array(
					'value' => 'fas fa-star',

				),
			)
		);

		$repeater->add_control(
			'tab_title',
			array(
				'label'       => __( 'Service Title', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Service Title', 'webvite' ),
				'label_block' => true,
			)
		);

		$repeater->add_control(
			'sub_tab_title',
			array(
				'label'       => __( 'Service Sub Title', 'webvite' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Service Sub Title', 'webvite' ),
				'label_block' => true,
			)
		);

		$repeater->add_control(
			'description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'webvite' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'webvite' ),
			]
		);
		
		$repeater->add_control(
			'infobox-link',
			[
				'label' => __( 'Link Enable', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);
		
		$repeater->add_control(
			'button-text',
			[
				'label' => __( 'Button Text', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
                'label_block' => true,
				'default' => __( 'Read More', 'webvite' ),
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'webvite' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'webvite' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['infobox-link' => 'yes']
			]
		);

		$this->add_control(
			'tabs',
			array(
				'label'       => __( 'Tabs Items', 'webvite' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'tab_title'   => __( 'Tab #1', 'webvite' ),
					),
				),
				'title_field' => '{{{ tab_title }}}',
			)
		);

		$this->end_controls_section(); 

		$this->start_controls_section(
			'slider-arrow-setting',
			[
				'label' => __( 'Slider Arrow Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'slider-arrow' );
	
			$this->start_controls_tab(
				'slider_arrow_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'normal_icon_color',
				[
					'label' => __( 'Icon Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-next i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-prev i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'normal_icon_bg_color',
				[
					'label' => __( 'Icon Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-next i' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-prev i' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'slider_arrow_hover',
				array(
					'label' => __( 'Hover', 'webvite' ),
				)
			);

			$this->add_control(
				'hover_icon_color',
				[
					'label' => __( 'Icon Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-next:hover i' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-prev:hover i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'hover_icon_bg_color',
				[
					'label' => __( 'Icon Background Color', 'webvite' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-next:hover i' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ps-services-slider .services-control-area .swiper-button-prev:hover i' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'pagination_number_color',
			[
				'label' => __( 'Pagination Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .swiper-container .swiper-pagination' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'style-info',
			[
				'label' => __( 'Services Info Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'services-bg-color',
			[
				'label' => __( 'Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'services-icon-color',
			[
				'label' => __( 'Icon Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-box-icon i' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'services-icon-color',
			[
				'label' => __( 'Icon Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-box-icon i' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'services-icon-bg-color',
			[
				'label' => __( 'BG Icon Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-bg-icon' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'title-info',
			[
				'label' => __( 'Title & Description Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'services-title-typography',
				'label' => __( 'Title Typography', 'webvite' ),
				'separator'   => 'before',
				'selector' => '{{WRAPPER}} .ps-services-slider .fancy-box-title',
			]
		);

		$this->add_control(
			'slider-title-color',
			[
				'label' => __( 'Title Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-box-title' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'slider-category-color',
			[
				'label' => __( 'Category Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-category' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description-title-typography',
				'label' => __( 'Description Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-box-content',
			]
		);

		$this->add_control(
			'slider-description-color',
			[
				'label' => __( 'Description Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-box-content' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->end_controls_section();
		
		$this->start_controls_section(
			'button-info',
			[
				'label' => __( 'Button Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'link-typography',
				'label' => __( 'Button Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-link a',
			]
		);

		$this->add_control(
			'slider-link-bg',
			[
				'label' => __( 'Button BG Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-link a' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'slider-link-color',
			[
				'label' => __( 'Button Text Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .ps-services-slider .fancy-box .fancy-box-info .fancy-link a' => 'color: {{VALUE}};',
		 		],
			]
		);
		
		$this->end_controls_section(); 

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();

		$tabs = $this->get_settings_for_display( 'tabs' );

		?>
		<div class="ps-services-slider">      
			<div class="swiper swiper-container ps-services-swiper" data-items="1" data-lg-items="1" data-md-items="1" data-sm-items="1" data-xs-items="1" data-space="30">
				<div class="services-title-area">
					<div class="section-title">
						<?php if($settings['sub-title-show'] == 'yes') {  ?>
						<span class="title-tagline"><?php echo sprintf('%1$s',esc_html($settings['sub-title'],'webvite')); ?></span>
						<?php } ?>
						<<?php echo $settings['title_html_tag']; ?> class="main-title"><?php echo sprintf('%1$s',esc_html($settings['title'],'webvite')); ?></<?php echo $settings['title_html_tag']; ?>>
					</div>
					<div class="services-control-area">
						<div class="services-swiper-pagination"></div>
						<div class="swiper-navigation-arrow">
							<div class="swiper-button-prev"><i class="ti-arrow-left"></i></div>
							<div class="swiper-button-next"><i class="ti-arrow-right"></i></div>
						</div>
					</div>
				</div>
				<div class="swiper-wrapper"> <!-- Wwiper Wrapper Start -->
					<?php 
					foreach ( $tabs as $index => $item ) {
						if ( ! empty( $item['image']['url'] ) ) {
							$this->add_render_attribute( 'image', 'src', $item['image']['url'] );
							$this->add_render_attribute( 'image', 'srcset', $item['image']['url'] );
							$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $item['image'] ) );
							$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $item['image'] ) );
							$image_html = Group_Control_Image_Size::get_attachment_image_html( $item, 'thumbnail', 'image' );
						}
						$icon_html = sprintf( '<i aria-hidden="true" class="%1$s"></i>', esc_attr( $item['webvite-icon']['value'], 'webvite' ) );
					?>
					<div class="swiper-slide"> <!-- Slide Start -->
					<div class="fancy-box">
						<div class="fancy-box-inner">
						<div class="fancy-box-img">
							<div class="fancy-img"><?php echo $image_html; ?></div>
						</div>
						<div class="fancy-box-info">
							<span class="fancy-bg-icon"><?php echo $icon_html; ?></span>
							<div class="fancy-info-inner">
								<span class="fancy-box-icon"><?php echo $icon_html; ?></span>
								<label class="fancy-category"><?php echo $item['sub_tab_title']; ?></label>
								<h5 class="fancy-box-title"><?php echo $item['tab_title']; ?></h5>
								<div class="fancy-box-content"><?php echo $item['description']; ?></div>
								<?php 
								if($item['infobox-link'] == 'yes') { 
								$url = $item['link']['url'];
								$this->add_render_attribute( 'servic-slider-class', 'href', esc_url($url) );
								?>
								<div class="fancy-link"><a <?php echo $this->get_render_attribute_string( 'servic-slider-class' ) ?>><span><?php echo sprintf('%1$s',esc_html($item['button-text'],'webvite'));?></span><i class="ti-arrow-top-right"></i></a></div>
								<?php } ?>
							</div>
						</div>
						</div>
					</div>
					</div> <!-- Slide End -->
					<?php } ?>
				</div> <!-- Wwiper Wrapper End -->
			</div>
		</div>
		<?php
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\service_slider() );
?>