<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class service extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve service widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'service', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve service widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Service Fancy', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the service widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve service widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register service widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	protected function _register_controls() {
			
		$this->start_controls_section(
			'list-items',
			[
				'label' => __( 'List Items', 'webvite' ),
			]
		);

		$repeater = new Repeater();
		
		$repeater->add_control(
			'title',
			[
				'label' => __( 'Infobox Title', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
				'default' => __( 'Infobox Title', 'webvite' ),
			]
		);

		$repeater->add_control(
			'description',
			[
				'label' => __( 'Description', 'webvite' ),
				'type' => Controls_Manager::TEXTAREA,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'webvite' ),
				'default' => __( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'webvite' ),
			]
		);

		$repeater->add_control(
			'webvite-icon',
			[
				'label' => __( 'Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star'
					
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'webvite' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$repeater->add_control(
			'service-div-link',
			[
				'label' => __( 'Link Enable', 'webvite' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'no',
				'yes' => __( 'yes', 'webvite' ),
				'no' => __( 'no', 'webvite' ),
			]
		);

		$repeater->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'link-typography',
				'label' => __( 'Link Typography', 'webvite' ),
				'condition' => ['service-div-link' => 'yes'],
				'selector' => '{{WRAPPER}} .feature-box .feature-link',
			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Button Link', 'webvite' ),
				'type' => Controls_Manager::URL,
				'dynamic' => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'webvite' ),
				'default' => [
					'url' => '#',
				],
				'condition' => ['service-div-link' => 'yes']
			]
		);

		$this->add_control(
			'tabs',
			array(
				'label'  => __( 'Slider Items', 'webvite' ),
				'type'   => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			)
		);

		$this->end_controls_section();  

		$this->start_controls_section(
			'section-setting',
			[
				'label' => __( 'Content Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'title-tag',
			[
				'label'      => __( 'Title Tag', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'h4',
				'options'    => [
					'h2'          => __( 'h2', 'webvite' ),
					'h3'          => __( 'h3', 'webvite' ),
					'h4'          => __( 'h4', 'webvite' ),
					'h5'          => __( 'h5', 'webvite' ),
					'h6'          => __( 'h6', 'webvite' ),					
				],
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label' => __( 'Title Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .services-fancy .services-fancy-item .services-title',
			]
		);

		$this->add_group_control(
		Group_Control_Typography::get_type(),
			[
				'name' => 'content-typography',
				'label' => __( 'Content Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .services-fancy .services-fancy-item .services-description',
			]
		);

		$this->start_controls_tabs('title_color_style',);

			$this->start_controls_tab(
				'service_title_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'title_color',
				array(
					'label'     => __( 'Title Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item .services-title a' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'description_color',
				array(
					'label'     => __( 'Description Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item .services-description' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'border_color',
				array(
					'label'     => __( 'Border Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item' => 'border-bottom-color: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'service_title_hover',
				array(
					'label' => __( 'Hover', 'webvite' ),
				)
			);

			$this->add_control(
				'title_hover_color',
				array(
					'label'     => __( 'Title Hover Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item:hover .services-title a' => 'color: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'style-service',
			[
				'label' => __( 'Style Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 30,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .services-fancy .services-fancy-item .services-icon' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'service_color_style' );

			$this->start_controls_tab(
				'service_icon_normal',
				array(
					'label' => __( 'Normal', 'webvite' ),
				)
			);

			$this->add_control(
				'service_icon_color',
				array(
					'label'     => __( 'Icon Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item .services-icon' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'service_icon_bg_color',
				array(
					'label'     => __( 'Icon BG Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item .services-icon' => 'background: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'arrow_color',
				array(
					'label'     => __( 'Arrow Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item .services-control .services-link' => 'color: {{VALUE}};',
					),
				)
			);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'service_icon_hover',
				array(
					'label' => __( 'Hover', 'webvite' ),
				)
			);

			$this->add_control(
				'service_icon_hover_color',
				array(
					'label'     => __( 'Icon Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item:hover .services-icon' => 'color: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'service_icon_bg_hover_color',
				array(
					'label'     => __( 'Icon BG Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item:hover .services-icon' => 'background: {{VALUE}};',
					),
				)
			);

			$this->add_control(
				'arrow_hover_color',
				array(
					'label'     => __( 'Arrow Hover Color', 'webvite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => array(
						'{{WRAPPER}} .services-fancy .services-fancy-item:hover .services-control .services-link' => 'color: {{VALUE}};',
					),
				)
			);

		$this->end_controls_tab();

		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		
		$settings = $this->get_settings();
		$tabs     = $this->get_settings_for_display( 'tabs' );
		?>
		<div class="services-fancy">
			<?php
			foreach ( $tabs as $index => $item ) {
				if ( ! empty( $item['image']['url'] ) ) 
				{
					$this->add_render_attribute( 'image', 'src', $item['image']['url'] );
					$this->add_render_attribute( 'image', 'srcset', $item['image']['url'] );
					$this->add_render_attribute( 'image', 'alt', Control_Media::get_image_alt( $item['image'] ) );
					$this->add_render_attribute( 'image', 'title', Control_Media::get_image_title( $item['image'] ) );
					$media_image = Group_Control_Image_Size::get_attachment_image_html( $item, 'thumbnail', 'image' );
				}
			
			
				$media_icon = sprintf('<i aria-hidden="true" class="%1$s"></i>',esc_attr($item['webvite-icon']['value'],'webvite'));
			

				$url = $item['link']['url'];
				$this->add_render_attribute( 'services-link', 'class', esc_attr('services-link') ); 
				$this->add_render_attribute( 'services-link', 'href', esc_url($url) );
						
				$color_type = sprintf('%1$s',esc_html($item['color-type'],'webvite'));
			?>
			<div class="services-fancy-item">
				<div class="services-item-inner">
					<div class="services-info">
						<div class="services-icon-title">
							<div class="services-icon"><?php echo $media_icon; ?></div>
							<?php if($item['title']) { ?>
							<<?php echo $settings['title-tag'];  ?> class="services-title"><a class="title-link" href="#"><?php echo sprintf('%1$s',esc_html($item['title'],'webvite')); ?></a></<?php echo $settings['title-tag'];  ?>>
						</div>
					<?php } if($item['description']) { ?>
					<span class="services-description"><?php echo sprintf('%1$s',esc_html($item['description'],'webvite'));?></span> 
					<?php } ?>
					</div>
					<?php
					if ( ! empty( $item['image']['url'] ) ) 
					{
					?>
					<div class="services-img">
						<?php echo $media_image; ?>
					</div>
					<?php } ?>
					<?php if($item['service-div-link'] == 'yes') { ?>
					<div class="services-control"><a <?php echo $this->get_render_attribute_string( 'services-link' ) ?>><i class="ti ti-arrow-top-right"></i></a></div>
					<?php } ?>
				</div>
			</div>
			<?php } ?>
		</div>


		
		<?php		
	}	
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\service() );
?>