<?php
namespace Elementor; 
if ( ! defined( 'ABSPATH' ) ) exit; 

/**
 * Elementor Blog widget.
 *
 * Elementor widget that displays an eye-catching headlines.
 *
 * @since 1.1.0
 */

class webvite_timeline extends Widget_Base {
	
	/**
	 * Get widget name.
	 *
	 * Retrieve timeline widget name.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget name.
	 */

	public function get_name() {
		return __( 'webvite_timeline', 'webvite' );
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve timeline widget title.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	
	public function get_title() {
		return __( 'Timeline', 'webvite' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the timeline widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */

	public function get_categories() {
		return [ 'webvite' ];
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve timeline widget icon.
	 *
	 * @since 1.1.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */

	public function get_icon() {
		return 'eicon-slider-push webvite-icon';
	}

	/**
	 * Register timeline widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 * @access protected
	 */

	 protected function _register_controls() {

		$this->start_controls_section(
			'general-setting',
			[
				'label' => __( 'General Setting', 'webvite' ),
			]
		);

		$this->add_control(
			'line_background',
			[
				'label' => __( 'Line BG Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-inner-wrapper:before' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->add_control(
			'small_line_background',
			[
				'label' => __( 'Small Line BG Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'separator'        => 'after',
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-content:before' => 'background: {{VALUE}};',
		 		],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'year-typography',
				'label'   => __( 'Year Typography', 'webvite' ),
				'separator'        => 'before',
				'selector' => '{{WRAPPER}} .timeline-wrapper .timeline-item .info-year',
			]
		);

		$this->add_control(
			'year_color',
			[
				'label' => __( 'Year Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'separator'        => 'after',
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .info-year' => 'color: {{VALUE}};',
		 		],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'date-typography',
				'label'   => __( 'Date Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .timeline-wrapper .timeline-item .info_date',
			]
		);

		$this->add_control(
			'date_color',
			[
				'label' => __( 'Date Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .info_date' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_section',
			[
				'label' => __( 'Timeline Items', 'webvite' ),
			]
		);

		$repeater = new Repeater();

        $repeater->add_control(
			'tab_title',
			[
				'label' => __( 'Title & Description', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'timeline Title', 'webvite' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'tab_content',
			[
				'label' => __( 'Content', 'webvite' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __( 'timeline Content', 'webvite' ),
				'show_label' => false,
			]
		);

		$repeater->add_control(
			'icon-type',
			[
				'label'      => __( 'Icon / Number', 'webvite' ),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'icon',
				'options'    => [
					// 'none'          => __( 'None', 'webvite' ),
					'icon'          => __( 'Icon', 'webvite' ),
					'number'        => __( 'Number', 'webvite' ),					
				]
			]
		);

		$repeater->add_control(
			'webvite-icon',
			[
				'label' => __( 'Icon', 'webvite' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'condition' => [
					'icon-type' => 'icon',
				],
				'default' => [
					'value' => 'ti ti-calendar'
					
				]
			]
		);

		$repeater->add_control(
			'webvite-number',
			[
				'label' => __( 'Number', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '1', 'webvite' ),
				'condition' => [
					'icon-type' => 'number',
				],
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'timeline_image',
			[
				'label' => __( 'Timiline Image', 'elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'label_off' => __( 'OFF', 'elementor' ),
				'label_on' => __( 'ON', 'elementor' ),
			]
		);

		$repeater->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'webvite' ),
				'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'condition' => [
					'timeline_image' => 'yes',
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				]
			]
		);

		$repeater->add_control(
			'info-date',
			[
				'label' => __( 'Date', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'May 2023', 'webvite' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'info-year',
			[
				'label' => __( 'Year', 'webvite' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( '2023', 'webvite' ),
				'dynamic' => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => __( 'timeline Items', 'webvite' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'tab_title' => __( ' These cases are perfectly simple.', 'webvite' ),
						'tab_content' => __( 'We make websites are the number one ranked design, build and marketing team. Creative and beautiful websites that will make you more successful. sunt in culpa qui officia deserunt mollit anim id est laborum.', 'webvite' ),
					],
				],
				'title_field' => '{{{ tab_title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'icon_setting',
			[
				'label' => __( 'Icon Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'icon_number_size',
			[
				'label' => __( 'Icon Number Size', 'webvite' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 32,   
				],
				'range' => [
					'px' => [
						'min' => 20,
						'max' => 40,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-number' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_number_background_color',
			[
				'label' => __( 'Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-number' => 'background: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_control(
			'icon_number_color',
			[
				'label' => __( 'Icon / Number Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-number' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_setting',
			[
				'label' => __( 'Title & Content Setting', 'webvite' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title-typography',
				'label'   => __( 'Title Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-title',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description-typography',
				'label'   => __( 'Description Typography', 'webvite' ),
				'selector' => '{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-description',
			]
		);

		$this->add_control(
			'background_color',
			[
				'label' => __( 'Background Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .content-wrapper' => 'background: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Tilte Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-title' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Description Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .timeline-description' => 'color: {{VALUE}};',
					'{{WRAPPER}} .timeline-wrapper .timeline-item .content-wrapper .timeline-date-year' => 'color: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->add_control(
			'description_line_color',
			[
				'label' => __( 'Description Line Color', 'webvite' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .timeline-wrapper .timeline-item .content-wrapper:before' => 'background: {{VALUE}};',
		 		],
				
				
			]
		);

		$this->end_controls_section();

	}
	/**
	 * Render Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 * @access protected
	 */
	
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>
		<div class="timeline-wrapper">
			<div class="timeline-inner-wrapper">
				<?php 
				foreach ( $settings['tabs'] as $index => $item ) : 

					if($item['icon-type'] == 'number')
					{
						$media_html = sprintf('%1$s',esc_html($item['webvite-number'],'webvite'));
					}
					if($item['icon-type'] == 'icon')
					{
						$media_html = sprintf('<i aria-hidden="true" class="%1$s"></i>',esc_attr($item['webvite-icon']['value'],'webvite'));
					}
				?>
				<div class="timeline-item">
					<?php if($item['icon-type'] != 'none') { ?>
					<div class="timeline-number"><span><?php echo $media_html; ?></span></div>
					<?php } ?>
					<div class="timeline-content">
						<div class="content-wrapper">
							<div class="timeline-date-year"><?php echo $item['info-date']; ?>  <?php echo $item['info-year']; ?></div>
							<h3 class="timeline-title"><?php echo $item['tab_title']; ?></h3>
							<div class="timeline-description"><?php echo $item['tab_content']; ?></div>
						</div>
					</div>
					<?php
					if($item['timeline_image'] = 'yes')
					{
					?>
					<div class="timeline-image">
						<img class="img-fluid" src="<?php echo $item['image']['url']; ?>" alt="">
					</div>
					<?php } ?>
					<div class="timeline-year">
						<div class="year-info-wrapper">
							<span class="info_date"><?php echo $item['info-date']; ?></span>
							<span class="info-year"><?php echo $item['info-year']; ?></span>
						</div>
					</div>
				</div>
				<?php 
				endforeach; 
				?>
			</div>
		</div>
		<?php
	}   
}
Plugin::instance()->widgets_manager->register_widget_type( new \Elementor\webvite_timeline() );
?>