<?php
/**
 * webvite core
 *
 * Plugin Name: Webvite Core
 * Description: Webvite plugin provides custom post type, elementor custom shortcode and redux options.
 * Author: Power-Squall
 * Version: 2.0.0
 * Author URI: http://webvite.powersquall.com/
 * Text Domain: webvite-core
 *
 * @package webvite Core
 */

define( 'webvite_THEME_ROOT', plugin_dir_path( __FILE__ ) );
if ( ! defined( 'webvite_THEME_URL' ) ) {
	define( 'webvite_THEME_URL', plugins_url( '', __FILE__ ) );
}

if ( ! function_exists( 'webvite_core_textdomain' ) ) {
	function webvite_core_textdomain() {
		load_plugin_textdomain( 'webvite-core', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
	}
	add_action( 'plugins_loaded', 'webvite_core_textdomain' );
}

// Redux Framework
if ( class_exists( 'ReduxFramework' ) ) {
	require_once webvite_THEME_ROOT . 'redux/opt-init.php';
}

require plugin_dir_path( __FILE__ ) . '/include/acf/page-options.php';
require plugin_dir_path( __FILE__ ) . '/include/shortcode.php';
require plugin_dir_path( __FILE__ ) . '/include/acf/post-format-quote.php';
require plugin_dir_path( __FILE__ ) . '/include/acf/post-format-audio.php';
require plugin_dir_path( __FILE__ ) . '/include/acf/post-format-video.php';

// Elementer
require_once webvite_THEME_ROOT . 'elementor/init.php';

// Widget
require_once webvite_THEME_ROOT . 'widget/class-webvite-widget-init.php';

// Post Type
require_once webvite_THEME_ROOT . 'post-type/testimonial.php';
require_once webvite_THEME_ROOT . 'post-type/portfolio.php';
require_once webvite_THEME_ROOT . 'post-type/team.php';

// Post Type
require_once webvite_THEME_ROOT . 'include/maintenance.php';

function webvite_core_script() {
	wp_enqueue_style( 'webvite-elements', webvite_THEME_URL . '/assest/css/elements.css', false, '1.0.0' );
	wp_enqueue_style( 'webvite-elements-responsive', webvite_THEME_URL . '/assest/css/elements-responsive.css', false, '1.0.0' );
	wp_enqueue_style( 'webvite-elements-admin', webvite_THEME_URL . '/assest/css/admin.css', false, '1.0.0' );
}
add_action( 'wp_enqueue_scripts', 'webvite_core_script' );

if ( ! function_exists( 'cardealer_get_all_registered_image_size_array' ) ) {
	/**
	 * Get all registered image size list array
	 */
	function cardealer_get_all_registered_image_size_array() {

		$registered_sizes = array();
		$sizes            = wp_get_registered_image_subsizes();

		foreach ( $sizes as $size_key => $size_label ) {
			$registered_sizes[$size_key] = $size_key . ' (' . $size_label['width'] . 'x' . $size_label['height'] . ')';
		}

		return $registered_sizes;
	}
}

add_action( 'cardealer_car_loop_link_open', 'cardealer_car_link_open', 10, 2 );
add_action( 'cardealer_car_loop_link_close', 'cardealer_car_link_close', 10, 2 );
if ( ! function_exists( 'cardealer_car_link_open' ) ) {
	/**
	 * Car link open.
	 *
	 * @param string $id .
	 * @param string $is_hover_overlay .
	 */
	function cardealer_car_link_open( $id, $is_hover_overlay ) {
		if ( 'no' === $is_hover_overlay ) {
			echo '<a href="' . esc_url( get_the_permalink( $id ) ) . '">';
		}
	}
}
if ( ! function_exists( 'cardealer_car_link_close' ) ) {
	/**
	 * Link close
	 *
	 * @param string $id .
	 * @param string $is_hover_overlay .
	 */
	function cardealer_car_link_close( $id, $is_hover_overlay ) {
		if ( 'no' === $is_hover_overlay ) {
			echo '</a>';
		}
	}
}

if ( ! function_exists( 'cardealer_get_cars_image' ) ) {
	/**
	 * Get cars images
	 *
	 * @param string $car_size .
	 * @param string $id .
	 */
	function cardealer_get_cars_image( $car_size = 'car_catalog_image', $id = null ) {
		if ( empty( $car_size ) ) {
			$car_size = 'car_catalog_image';
		}
		global $post;
		$car_id = ( isset( $id ) && null !== $id ) ? $id : $post->ID;
		if ( function_exists( 'get_field' ) ) {
			$images = get_field( 'car_images', $car_id );

			if ( ! empty( $images ) ) {
				if ( ( isset( $_POST['action'] ) && 'cardealer_load_more_vehicles' === $_POST['action'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
					$img = '<img class="img-responsive" alt="' . esc_attr( $images[0]['alt'] ) . '" width="' . esc_attr( $images[0]['sizes'][ $car_size . '-width' ] ) . '" height="' . esc_attr( $images[0]['sizes'][ $car_size . '-height' ] ) . '" src="' . esc_url( $images[0]['sizes'][ $car_size ] ) . '"/>';
				} elseif ( cardealer_lazyload_enabled() && isset( $images[0]['sizes'] ) && isset( $images[0]['alt'] ) ) {
					$img = '<img class="img-responsive cardealer-lazy-load" alt="' . esc_attr( $images[0]['alt'] ) . '" width="' . esc_attr( $images[0]['sizes'][ $car_size . '-width' ] ) . '" height="' . esc_attr( $images[0]['sizes'][ $car_size . '-height' ] ) . '" src="' . esc_url( LAZYLOAD_IMG ) . '" data-src="' . esc_url( $images[0]['sizes'][ $car_size ] ) . '"/>';
				} else {
					if ( isset( $images[0]['sizes'] ) && isset( $images[0]['alt'] ) && isset( $images[0]['sizes'][ $car_size ] ) ) {
						$img = '<img class="img-responsive" src="' . esc_url( $images[0]['sizes'][ $car_size ] ) . '" alt="' . esc_attr( $images[0]['alt'] ) . '" width="' . esc_attr( $images[0]['sizes'][ $car_size . '-width' ] ) . '" height="' . esc_attr( $images[0]['sizes'][ $car_size . '-height' ] ) . '"/>';
					} else {
						$img = cardealer_get_carplaceholder( $car_size );
					}
				}
			} else {
				$img = cardealer_get_carplaceholder( $car_size );
			}
		} else {
			$img = cardealer_get_carplaceholder( $car_size );
		}
		return $img;
	}
}

if ( ! function_exists( 'cardealer_get_carplaceholder' ) ) {
	/**
	 * Default cars placeholder image
	 *
	 * @param string $size .
	 * @param string $return_type .
	 */
	function cardealer_get_carplaceholder( $size = '', $return_type = 'image' ) {

		//$url  = CDHL_URL;
		$url .= wp_get_attachment_image_url( get_post_thumbnail_id( $post->ID ) );
		if ( '' !== $size ) {
			if ( 'car_thumbnail' === $size ) {
				$meta = 'width="190" height="138"';
			} elseif ( 'car_list_thumbnail' === $size ) {
				$meta = 'width="110" height="79"';
			} elseif ( 'large' === $size || 'car_single_image' === $size ) {
				$meta = 'class="img-responsive"';
			} elseif ( 'car_tabs_image' === $size ) {
				$meta = 'class="img-responsive"';
			} elseif ( 'cardealer-50x50' === $size ) {
				$meta = 'width="50" height="50"';
			} else {
				$meta = 'width="265" height="190"';
			}
		}

		return ( ! empty( $return_type ) && 'image' === $return_type ) ? '<img src="' . esc_url( $url ) . '" class="img-responsive" ' . $meta . ' alt="carplaceholder"/>' : $url;
	}
}

if ( ! function_exists( 'cardealer_get_cars_owl_image' ) ) {

	/**
	 * Get cars images for owl carousal
	 *
	 * @param string $car_size .
	 * @param string $id .
	 */
	function cardealer_get_cars_owl_image( $car_size = 'car_catalog_image', $id = null ) {
		if ( empty( $car_size ) ) {
			$car_size = 'car_catalog_image';
		}
		global $post;
		$car_id = ( isset( $id ) && null !== $id ) ? $id : $post->ID;
		if ( function_exists( 'get_field' ) ) {
			$images = get_field( 'car_images', $car_id );
			if ( ! empty( $images ) ) {
				if ( ( isset( $_POST['action'] ) && 'cardealer_load_more_vehicles' === $_POST['action'] ) || cardealer_lazyload_enabled() ) { // phpcs:ignore WordPress.Security.NonceVerification
					$img = '<img class="img-responsive owl-lazy" alt="' . esc_attr( $images[0]['alt'] ) . '" width="' . esc_attr( $images[0]['sizes'][ $car_size . '-width' ] ) . '" height="' . esc_attr( $images[0]['sizes'][ $car_size . '-height' ] ) . '" src="' . esc_url( LAZYLOAD_IMG ) . '" data-src="' . esc_url( $images[0]['sizes'][ $car_size ] ) . '"/>';
				} else {
					$img = '<img class="img-responsive" src="' . esc_url( $images[0]['sizes'][ $car_size ] ) . '" alt="' . esc_attr( $images[0]['alt'] ) . '" width="' . esc_attr( $images[0]['sizes'][ $car_size . '-width' ] ) . '" height="' . esc_attr( $images[0]['sizes'][ $car_size . '-height' ] ) . '"/>';
				}
			} else {
				$img = cardealer_get_carplaceholder( $car_size );
			}
		} else {
			$img = cardealer_get_carplaceholder( $car_size );
		}
		return $img;
	}
}

if ( ! function_exists( 'cardealer_is_hover_overlay' ) ) {
	/**
	 * Hover overlay
	 */
	function cardealer_is_hover_overlay() {
		global $car_dealer_options;
		$is_hover_overlay = 'yes';
		if ( isset( $car_dealer_options['cars-is-hover-overlay-on'] ) && ! empty( $car_dealer_options['cars-is-hover-overlay-on'] ) ) {
			$is_hover_overlay = $car_dealer_options['cars-is-hover-overlay-on'];
		}
		return $is_hover_overlay;
	}
}