<?php
/**
 * Header Options
 *
 * @package webvite Core
 * @subpackage Core
 * @since 1.1.0
 * @version 1.1.0
 */

Redux::setSection(
	'webvite_redux',
	array(
		'title'            => esc_html__( 'Site Header', 'webvite' ),
		'id'               => 'header-editor',
		'icon'             => 'el el-arrow-up',
		'customizer_width' => '500px',
	)
);

Redux::setSection(
	'webvite_redux',
	array(
		'title'      => esc_html__( 'Topbar', 'webvite' ),
		'id'         => 'header-opt',
		'subsection' => true,
		'desc'       => esc_html__( '', 'webvite' ),
		'fields'     => array(

			array(
				'id'    => 'info_site_header_top',
				'type'  => 'info',
				'style' => 'custom',
				'color' => sanitize_hex_color( '#2b2b2b' ),
				'title' => __( 'Layout Options', 'webvite' ),
				'desc'  => __( 'This Section Contain Option For Your Site Layout.', 'webvite' ),
			),

			array(
				'id'     => 'section-general',
				'type'   => 'section',
				'indent' => true,
			),

			array(
				'id'       => 'header_top',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Display Topbar', 'webvite' ),
				'subtitle' => esc_html__( 'Turn on to display the Email and Phone, Login and Button on header menu.', 'webvite' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'webvite' ),
					'off' => esc_html__( 'Off', 'webvite' ),
				),
				'default'  => esc_html__( 'off', 'webvite' ),
			),

			array(
				'id'       => 'header_topbar_mobile',
				'type'     => 'button_set',
				'title'    => __( 'Topbar Mobile', 'webvite' ),
				'required' => array( 'header_top', '=', 'on' ),
				'compiler' => 'true',
				'options'  => array(
					'topbar-mobile-on' => 'On',
					'topbar-mobile-off' => 'Off',
				),
				'default'  => 'topbar-mobile-off',
			),

			array(
				'id'       => 'header-top-blocks',
				'type'     => 'sorter',
				'title'    => 'Topbar Elements',
				'desc'     => 'Organize how you want the layout to appear on the homepage',
				'required' => array( 'header_top', '=', 'on' ),
				'compiler' => 'true',
				'options'  => array(
					'Left'               => array(
						'email' => 'Email',
						'phone' => 'Phone',
					),
					'Right'              => array(
						'text'         => 'Text',
						'social-media' => 'Social Media',
					),
					'Available Elements' => array(
						'topbar-menu' => 'Topbar Menu',
					),
				),
			),

			array(
				'id'          => 'top_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Background Color', 'webvite' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Text/Link Color', 'webvite' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#757887',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_link_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Link Hover Color', 'webvite' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'top_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Icon Color', 'webvite' ),
				'required'    => array( 'header_top', '=', 'on' ),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),


		),

	)
);

Redux::setSection(
	'webvite_redux',
	array(
		'title'            => esc_html__( 'Header Main', 'webvite' ),
		'id'               => 'header-main',
		'subsection'       => true,
		'customizer_width' => '400px',
		'desc'             => esc_html__( 'This section contains options for header.', 'webvite' ),
		'fields'           => array(

			array(
				'id'       => 'header_type',
				'type'     => 'image_select',
				'title'    => esc_html__( 'Header Layout', 'webvite' ),
				'subtitle' => esc_html__( 'Select the design variation that you want to use for site header.', 'webvite' ),
				'options'  => array(
					'1' => array(
						'alt' => 'Style1',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-1.jpg',
					),
					'2' => array(
						'alt' => 'Style2',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-2.jpg',
					),
					'3' => array(
						'alt' => 'Style3',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-3.jpg',
					),
					'4' => array(
						'alt' => 'Hamburger',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-4.jpg',
					),
					'5' => array(
						'alt' => 'Leftmenu',
						'img' => get_template_directory_uri() . '/assets/images/theme-option/site-header/header-5.jpg',
					),
				),
				'default'  => '1',
			),

			array(
				'id' => 'section-leftmenu-logo',
				'type' => 'section',  
				'required' => array(
					array( 'header_type', '=', '5' ),
				),          
				'indent' => true
			) ,
	
			array(
				'id'       => 'leftmenu_logo_type',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Leftmenu Logo Setting', 'webvite' ),
				'subtitle' => esc_html__( 'Select this option for Logo as Text/Image.', 'webvite' ),
				'options'  => array(
					'1' => ' Logo as Text',
					'2' => ' Logo as Image',
				),
				'default'  => '2'
			),
	
			array(
				'id'       => 'leftmenu_logo',         
				'type'     => 'media',
				'url'      => false,
				'title'    => esc_html__( 'Leftmenu Logo','webvite'),
				'required'  => array( 'leftmenu_logo_type', '=', '2' ),
				'read-only'=> false,
				'default'  => array( 'url' => get_template_directory_uri() .'/assets/images/logo.svg' ),
				'subtitle' => esc_html__( 'Upload Logo image for your Website. Otherwise site title will be displayed in place of Logo.','webvite'),
			), 
	
			array(
				'id'             => 'leftmenu_logo_height',
				'type'           => 'dimensions',
				'units'          => array( 'em', 'px', '%' ),    // You can specify a unit value. Possible: px, em, %
				'units_extended' => 'true',  // Allow users to select any type of unit
				'title'          => __( 'Leftmenu Logo Height', 'webvite' ),
				'required'  => array( 'leftmenu_logo_type', '=', '2' ),
				'subtitle'       => __( 'Set a Custom Height for your upload logo.', 'webvite' ),
				'output'    => array( '.site-header .header-logo img' ),
				'width'         => false,
			),
	
			array(
				'id'       => 'leftmenu_inner_logo',         
				'type'     => 'media',
				'url'      => false,
				'title'    => esc_html__( 'Leftmenu Overlay Logo','webvite'),
				'required'  => array( 'leftmenu_logo_type', '=', '2' ),
				'read-only'=> false,
				'default'  => array( 'url' => get_template_directory_uri() .'/assets/images/logo.svg' ),
				'subtitle' => esc_html__( 'Upload Sticky Logo.','webvite'),
			), 
	
			array(
				'id'             => 'leftmenu_sticky_logo_height',
				'type'           => 'dimensions',
				'units'          => array( 'em', 'px', '%' ),    // You can specify a unit value. Possible: px, em, %
				'units_extended' => 'true',  // Allow users to select any type of unit
				'title'          => __( 'Leftmenu Ovarlay Logo Height', 'webvite' ),
				'required'  => array( 'leftmenu_logo_type', '=', '2' ),
				'subtitle'       => __( 'Set a Custom Height for your Sticky upload logo.', 'webvite' ),
				'output'    => array( '.site-header.sticky .header-logo img' ),
				'width'         => false,
			),
		
			array(
				'id'       => 'leftmenu_logo_text',
				'type'     => 'text',
				'title'    => esc_html__( 'Logo Text', 'webvite' ),
				'desc'     => esc_html__( 'Enter the text to be used instead of the logo image', 'webvite' ),
				'required'  => array( 'leftmenu_logo_type', '=', '1' ),
				'msg'      => esc_html__('custom error message','webvite' ),
				'default'  => esc_html__('webvite','webvite' ),
			),
	
			array(
				'id'          => 'leftmenu_logo_font',
				'type'        => 'typography',
				'title'       => __( 'Logo Typography', 'webvite' ),
				'required'  => array( 'leftmenu_logo_type', '=', '1' ),
				'compiler'      => true,  // Use if you want to hook in your own CSS compiler
				'google'      => true,
				'font-style'    => true, // Includes font-style and weight. Can use font-style or font-weight to declare
				'subsets'       => false, // Only appears if google is true and subsets not set to false
				'font-size'     => true,
				'line-height'   => true,
				'word-spacing'  => false,  // Defaults to false
				'letter-spacing'=> true,  // Defaults to false
				'color'         => false,
				'preview'       => false, // Disable the previewer
				'all_styles'  => false,
				// Enable all Google Font style/weight variations to be added to the page
				'output'      => array( '.site-header.header-leftmenu .leftmenu-header-logo .logo-type-text .site-logo-text', '.hamburger-leftmenu .leftmenu-header-logo .logo-type-text .site-logo-text' ),
				// An array of CSS selectors to apply this font style to dynamically
				'compiler'    => array( 'site-description-compiler' ),
				// An array of CSS selectors to apply this font style to dynamically
				'units'       => 'px',
				'subtitle'    => __( 'Typography option with each property can be called individually.', 'webvite' ),
				'default'     => array(
					'font-family' => 'Abel',
					'google'      => true,
					'font-size'   => '50px',
				),
			),
	
			array(
				'id'            => 'leftmenu_logo_color',
				'type'          => 'color',
				'title'         => esc_html__( 'Logo Text Color', 'webvite' ),
				'subtitle'      => esc_html__( 'Choose Text Color', 'webvite' ),
				'required'      => array( 'leftmenu_logo_type', '=', '1' ),
				'default'       =>'#ffffff',
				'mode'          => 'color',
				'output'      => array('.site-header.header-leftmenu .leftmenu-header-logo .logo-type-text .site-logo-text'),
				'transparent'   => false
			),

			array(
				'id'            => 'leftmenu_logo_ovarlay_color',
				'type'          => 'color',
				'title'         => esc_html__( 'Ovarlay Logo Text Color', 'webvite' ),
				'subtitle'      => esc_html__( 'Choose Text Color', 'webvite' ),
				'required'      => array( 'leftmenu_logo_type', '=', '1' ),
				'default'       =>'#ffffff',
				'mode'          => 'color',
				'output'      => array('.hamburger-leftmenu .leftmenu-header-logo .logo-type-text .site-logo-text'),
				'transparent'   => false
			),

			array(
				'id' => 'section-header-setting',
				'type' => 'section',            
				'indent' => true
			),

			array(
				'id'       => 'header_setting',
				'type'     => 'button_set',
				'title'    => __( 'Header Setting', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '2' ),
					array( 'header_type', '!=', '5' ),
				),
				'subtitle' => __( 'Select the Header Setting want to use with site header.', 'webvite' ),
				'options'  => array(
					'header-default' => 'Default',
					'header-transparnt' => 'Transparnt',
					'header-transparnt-light' => 'Transparnt Light',
					'header-transparnt-light header-fix' => 'Transparnt Fix',
				),
				'default'  => 'header-default',
			),

			array(
				'id'       => 'header_trigger',
				'type'     => 'button_set',
				'title'    => __( 'Header Sidemenu Trigger', 'webvite' ),
				'required' => array( 'header_type', '=', '3' ),
				'subtitle' => __( 'Select Sidemenu Trigger Background Color.', 'webvite' ),
				'options'  => array(
					'sidemenu-trigger-primary' => 'Primary',
					'sidemenu-trigger-primary-second' => 'Primary Second',
					'sidemenu-trigger-dark' => 'Dark',
					'sidemenu-trigger-custom' => 'Custom',
				),
				'default'  => 'sidemenu-trigger-primary',
			),

			array(
				'id'       => 'header-width',
				'type'     => 'button_set',
				'title'    => __( 'Header Width', 'webvite' ),
				//'required' => array( 'header_type', '=', '1' ),
				'required' => array(
					array( 'header_type', '!=', '2' ),
					array( 'header_type', '!=', '3' ),
					array( 'header_type', '!=', '5' ),
				),
				'subtitle' => __( 'Select the Header Container Size want to use with site header.', 'webvite' ),
				'options'  => array(
					'container-width' => 'Container',
					'full-width' => 'Full Width',
				),
				'default'  => 'container-width',
			),

			array(
				'id'          => 'header_trigger_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Trigger Background Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '3' ),
					array( 'header_trigger', '=', 'sidemenu-trigger-custom' ),
				),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_trigger_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Trigger Icon Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '3' ),
					array( 'header_trigger', '=', 'sidemenu-trigger-custom' ),
				),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Header Background Color

			array(
				'id'     => 'header-color-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Color Setting', 'webvite' ),
				'indent' => true,
			),

			array(
				'id'       => 'header-color',
				'type'     => 'button_set',
				'title'    => __( 'Header Color Option', 'webvite' ),
				'subtitle' => __( 'Set Header Custom Color Setting.', 'webvite' ),
				'options'  => array(
					'header-color-default' => 'Default',
					'header-color-custom' => 'Custom',
				),
				'default'  => 'header-color-default',
			),

			array(
				'id'          => 'header_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Background Color', 'webvite' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),
			
			array(
				'id'          => 'header_menu_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Background Color', 'webvite' ),
				//'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'required' => array(
					array( 'header_type', '=', '2' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Text/Link Color', 'webvite' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#757887',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_link_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Header Link Hover Color', 'webvite' ),
				'required'       => array( 'header-color', '=', 'header-color-custom' ),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Header Infobox Color Option
			array(
				'id'     => 'header-info-color-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Info Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header_type', '!=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),

				'indent' => true,
			),

			array(
				'id'          => 'header_info_icon_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Icon Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header_type', '!=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_info_title_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Title Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header_type', '!=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#000d44',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_info_content_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Info Content Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '1' ),
					array( 'header_type', '!=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#757575',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Header Hamburger PopUp Color Option
			array(
				'id'     => 'header-hamburger-color-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Hamburger Color Setting', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),

				'indent' => true,
			),

			array(
				'id'          => 'header_hamburger_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Background Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#10131c',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_hamburger_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Normal Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#ffffff',
				'mode'        => 'background',
				'transparent' => false,
			),

			array(
				'id'          => 'header_hamburger_active_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Active Color', 'webvite' ),
				'required' => array(
					array( 'header_type', '=', '4' ),
					array( 'header-color', '=', 'header-color-custom' ),
				),
				'default'     => '#ef2c34',
				'mode'        => 'background',
				'transparent' => false,
			),

			// Sticky Header Setting

			array(
				'id'     => 'header-sticky-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Sticky', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '5' ),
				),
				'indent' => true,
			),

			array(
				'id'       => 'header_sticky',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Sticky', 'webvite' ),
				'subtitle' => esc_html__( 'Turn on to display enable the sticky header.', 'webvite' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'webvite' ),
					'off' => esc_html__( 'Off', 'webvite' ),
				),
				'default'  => esc_html__( 'on', 'webvite' ),
			),

			array(
				'id'     => 'header-search-section',
				'type'   => 'section',
				'title'  => esc_html__( 'Header Search', 'webvite' ),
				'required' => array(
					array( 'header_type', '!=', '5' ),
				),
				'indent' => true,
			),


			array(
				'id'       => 'header_search',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Search', 'webvite' ),
				'subtitle' => esc_html__( 'Turn on to display the search Icon in top header.', 'webvite' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'webvite' ),
					'off' => esc_html__( 'Off', 'webvite' ),
				),
				'default'  => esc_html__( 'on', 'webvite' ),
			),

			array(
				'id'     => 'header-submenu-color',
				'type'   => 'section',
				'title'  => esc_html__( 'Submenu Color', 'webvite' ),
				'indent' => true,
			),

			array(
				'id'       => 'submenu-color',
				'type'     => 'button_set',
				'title'    => __( 'Submenu Color Scheme', 'webvite' ),
				'subtitle' => esc_html__( 'Choose Submenu Color Scheme.', 'webvite' ),
				'options'  => array(
					'submenu-light' => 'Light',
					'submenu-dark' => 'Dark',
				),
				'default'  => 'submenu-light',
			),

			array(
				'id'     => 'header_custom_font',
				'type'   => 'section',
				'title'  => esc_html__( 'Menu Typography', 'webvite' ),
				'indent' => true,
			),

			array(
				'id'       => 'nav-typography',
				'type'     => 'button_set',
				'title'    => __( 'Menu Typography', 'webvite' ),
				'subtitle' => __( 'Specify the Main Navigation font properties.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'1' => 'Default',
					'2' => 'Custom',
				),
				'default'  => '1',
			),

			array(
				'id'             => 'button-typography2',
				'type'           => 'typography',
				'title'          => __( 'Menu Font', 'webvite' ),
				'subtitle'       => __( 'Specify the Header Menu font properties.', 'webvite' ),
				'required'       => array( 'nav-typography', '=', '2' ),
				'google'         => true,
				'letter-spacing' => true,
				'font-backup'    => false,
				'text-transform' => true,
				'text-align'     => false,
				'color'          => false,
				'output'         => array( '.main-navigation .navbar-nav > li > a', '.hamburger-overlay .hamburger-navigation .nav li a', '.hamburger-leftmenu .leftmenu-navigation .nav > li > a' ),
			),

		),
	)
);

Redux::setSection(
	'webvite_redux',
	array(
		'title'            => esc_html__( 'Header Button', 'webvite' ),
		'id'               => 'header-button',
		'subsection'       => true,
		'customizer_width' => '400px',
		'desc'             => esc_html__( 'This section contains options for header.', 'webvite' ),
		'fields'           => array(

			array(
				'id'       => 'header_button',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Header Button', 'webvite' ),
				'subtitle' => esc_html__( 'Turn on to display the Header button in top header.', 'webvite' ),
				'options'  => array(
					'on'  => esc_html__( 'On', 'webvite' ),
					'off' => esc_html__( 'Off', 'webvite' ),
				),
				'default'  => esc_html__( 'on', 'webvite' ),
			),

			array(
				'id'       => 'header_btn_typography',
				'type'     => 'button_set',
				'title'    => __( 'Button Typography', 'webvite' ),
				'subtitle' => __( 'Choose Header Button font properties.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'1' => 'Default',
					'2' => 'Custom',
				),
				'default'  => '1',
			),

			array(
				'id'             => 'button-typography',
				'type'           => 'typography',
				'title'          => __( 'Button Font', 'webvite' ),
				'subtitle'       => __( 'Specify the Header Button font properties.', 'webvite' ),
				'required'       => array( 'header_btn_typography', '=', '2' ),
				'google'         => true,
				'letter-spacing' => true,
				'font-backup'    => false,
				'text-transform' => true,
				'text-align'     => false,
				'color'          => false,
			),

			array(
				'id'       => 'button_title',
				'type'     => 'text',
				'title'    => esc_html__( 'Button Text', 'webvite' ),
				'subtitle' => __( 'Add Button text.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'default'  => 'Get Started',
				'desc'     => esc_html__( 'Change Title (e.g.Download).', 'webvite' ),
			),

			array(
				'id'       => 'button_link',
				'type'     => 'text',
				'title'    => esc_html__( 'Button Link', 'webvite' ),
				'subtitle' => __( 'Add Button link.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'desc'     => esc_html__( 'Add download link.', 'webvite' ),
			),

			array(
				'id'       => 'button_style',
				'type'     => 'button_set',
				'title'    => __( 'Button Style', 'webvite' ),
				'subtitle' => __( 'Select Button Style.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-flat' => 'Flat',
					'button-border' => 'Border',
				),
				'default'  => 'button-flat',
				'desc'     => esc_html__( 'Button Style Option Not Working in Header Style 2.', 'webvite' ),
			),

			array(
				'id'       => 'button_shap',
				'type'     => 'button_set',
				'title'    => __( 'Button Shap', 'webvite' ),
				'subtitle' => __( 'Choose Button Shap.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-square' => 'Square',
					'button-round' => 'Round',
					'button-rounded' => 'Rounded',
				),
				'default'  => 'button-square',
				'desc'     => esc_html__( 'Button Shap Option Not Working in Header Style 2.', 'webvite' ),
			),

			array(
				'id'       => 'button_color',
				'type'     => 'button_set',
				'title'    => __( 'Button Color', 'webvite' ),
				'subtitle' => __( 'Choose Button Color Scheme.', 'webvite' ),
				'required' => array( 'header_button', '=', 'on' ),
				'options'  => array(
					'button-dark' => 'Dark',
					'button-light' => 'Light',
					'button-theme' => 'Primary',
					'button-gradient' => 'Gradient',
					'button-theme-second' => 'Primary Second',
				),
				'default'  => 'button-dark',
			),
		),
	)
);


// Redux::setSection(
// 	'webvite_redux',
// 	array(
// 		'title'            => esc_html__( 'Header Sidemenu', 'webvite' ),
// 		'id'               => 'header-sidemenu',
// 		'subsection'       => true,
// 		'customizer_width' => '400px',
// 		'desc'             => esc_html__( 'This section contains options for header.', 'webvite' ),
// 		'fields'           => array(

// 			array(
// 				'id'       => 'header_sidemenu',
// 				'type'     => 'button_set',
// 				'title'    => esc_html__( 'Header Sidemenu', 'webvite' ),
// 				'subtitle' => esc_html__( 'Turn on to display the Header button in top header.', 'webvite' ),
// 				'options'  => array(
// 					'on'  => esc_html__( 'On', 'webvite' ),
// 					'off' => esc_html__( 'Off', 'webvite' ),
// 				),
// 				'default'  => esc_html__( 'on', 'webvite' ),
// 			),
// 		),
// 	)
// );
